/********************************************************************************
  * @file    PT32x030x.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for interrupt number,MCU registers and bits 
  ******************************************************************************
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

    
#ifndef PT32x030x_H
#define PT32x030x_H

#ifdef __cplusplus
 extern "C" {
#endif

#if defined (__CC_ARM)
#pragma anon_unions
#endif	

#define __CM0_REV			0 					/*!< Core Revision r0p0	*/
#define __MPU_PRESENT		0 				/*!< x030x do not provide MPU	*/
#define __NVIC_PRIO_BITS	2 			/*!< x030x uses 2 Bits for the Priority Levels  */
#define __Vendor_SysTickConfig	0 /*!< Set to 1 if different SysTick Config is used  */
#define _PT32x030x								/*!< MCU Type*/

/**
 * @brief 030 Interrupt Number Definition
 */	
typedef enum IRQn
{
	/******  Cortex-M0 Processor Exceptions Numbers ***************************************************/
	NMI_IRQn        = -14,	/*!< 2 Non Maskable Interrupt*/
	HardFault_IRQn	= -13,	/*!< 3 Cortex-M0 Hard Fault Interrupt*/
	SVCall_IRQn		= -5,			/*!< 11 Cortex-M0 SV Call Interrupt	*/
	PendSV_IRQn	    = -2,		/*!< 14 Cortex-M0 Pend SV Interrupt	*/
	SysTick_IRQn	= -1,			/*!< 15 Cortex-M0 System Tick Interrupt*/

	/****** MCU Specific Interrupt Numbers *******************************************************/
	PLLFAIL_IRQn 	=  1 ,  		/* PLLFAIL     Interrupt  */
	IFMC_IRQn    	=  3 ,  		/* IFMC        Interrupt  */
  DMA_IRQn    	=  4 ,  		/* DMA         Interrupt  */
	EXTIA_IRQn    =  5 ,  		/* PA          Interrupt  */
	EXTIB_IRQn    =  6 , 			/* PB          Interrupt  */
	EXTIC_IRQn    =  7,				/* PC          Interrupt  */
	EXTIF_IRQn    =  8,				/* PF          Interrupt  */
	CMP0_IRQn	    =  9 ,  		/* Comparator0 Interrupt  */
	CMP1_IRQn	    =  10,  		/* Comparator1 Interrupt 	*/
  CMP2_IRQn	    =  11, 	  	/* Comparator2 Interrupt 	*/
	ADC_IRQn      =  12,  		/* ADC         Interrupt 	*/
	TIM1_IRQn     =  13,  		/* TIMER1      Interrupt 	*/ 
	TIM4_IRQn     =  15,  		/* TIMER4      Interrupt 	*/
	TIM3_IRQn     =  16,  		/* TIMER3      Interrupt 	*/
	TIM2_IRQn     =  17, 	  	/* TIMER2      Interrupt 	*/
  ALU_IRQn      =  18, 		 	/* ALU         Interrupt 	*/
	PVD_IRQn      =  20,  		/* PVD         Interrupt 	*/
	I2C0_IRQn     =  23,  		/* I2C0        Interrupt 	*/
  I2C1_IRQn     =  24,  		/* I2C1        Interrupt 	*/
	SPI0_IRQn     =  25,  		/* SPI0        Interrupt 	*/
	SPI1_IRQn     =  26,  		/* SPI1        Interrupt 	*/
	UART0_IRQn    =  27,  		/* UART0       Interrupt 	*/
  UART1_IRQn    =  28,  		/* UART1       Interrupt 	*/
	TIM5_IRQn     =  29, 	  	/* TIM5        Interrupt 	*/
  TIM6_IRQn     =  30,  		/* TIM6        Interrupt 	*/
  TIM7_IRQn     =  31,  		/* TIM7        Interrupt 	*/
} IRQn_Type;


#include "core_cm0.h"
#include "PT32x030x_Type.h"
#include "system_PT32x030x.h"
#include <stdint.h>


/** @addtogroup Exported_types
  * @{
  */  
typedef enum {RESET = 0, SET = !RESET} FlagStatus, ITStatus, RemapStatus, ProtectStatus,BitAction;

typedef enum {DISABLE = 0, ENABLE = !DISABLE} FunctionalState;
#define IS_FUNCTIONAL_STATE(STATE) (((STATE) == DISABLE) || ((STATE) == ENABLE))

#define wb(addr, value)     (*((uint8_t  volatile *) (addr)) = value)
#define rb(addr)            (*((uint8_t  volatile *) (addr)))
#define whw(addr, value)    (*((u16 volatile *) (addr)) = value)
#define rhw(addr)           (*((u16 volatile *) (addr)))
#define ww(addr, value)     (*((u32 volatile *) (addr)) = value)
#define rw(addr)            (*((u32 volatile *) (addr)))

#define ResetBit_BB(Addr, BitNumber) (rw(Addr) &= ~(1UL << BitNumber))
#define SetBit_BB(Addr, BitNumber)   (rw(Addr) |= (1UL << BitNumber))
#define GetBit_BB(Addr, BitNumber)   ((rw(Addr) >> BitNumber) & 1UL)

typedef enum {ERROR = 0, SUCCESS = !ERROR} ErrorStatus;
typedef enum {FALSE = 0, TRUE = !FALSE} bool;

/** @defgroup ID_TypeDef
* @{ 
*/
typedef struct
{
	__I  u32  UDID;     /*!< Offset: 0x000 User Define Identifier Register 					(R) */
	u32 RESERVED0[3]; 	/*!< Reserved 										   														*/
	__I  u32  UID1;   	/*!< Offset: 0x010 Unique Product Identification Register 1 (R) */ 
	__I  u32  UID2;   	/*!< Offset: 0x014 Unique Product Identification Register 2 (R) */
	__I  u32  UID3;   	/*!< Offset: 0x018 Unique Product Identification Register 3 (R) */ 
	__I  u32  CID;      /*!< Offset: 0x01C Chip Configration Identifier Register 		(R) */
} ID_TypeDef;

/** @defgroup GPIO_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32  DR;        	/*!< Offset: 0x000 DATA Register 														 (R/W) */
	u32  RESERVED1;       /*!< Offset: 0x004 Reserved 																			 */	
	__IO u32  OES;				/*!< Offset: 0x008 Output Enable Set Register  							 (R/W) */
	__IO u32  OEC; 				/*!< Offset: 0x00C Output Enable Clear Register  						 (R/W) */
	u32  RESERVED2[12];		/*!< Offset: 0x010 Reserved 																			 */
	__IO u32  PUS;				/*!< Offset: 0x040 Pull Up Set Register  										 (R/W) */
	__IO u32  PUC;				/*!< Offset: 0x044 Pull Up Clear Register  									 (R/W) */
	__IO u32  PDS;				/*!< Offset: 0x048 Pull Down Set Register  									 (R/W) */
	__IO u32  PDC;				/*!< Offset: 0x04C Pull Down Clear Register  								 (R/W) */
	__IO u32  ODS;				/*!< Offset: 0x050 Open Drain Set Register  								 (R/W) */
	__IO u32  ODC;				/*!< Offset: 0x054 Open Drain Clear Register  							 (R/W) */
    u32  RESERVED3[6];  /*!< Offset: 0x010 Reserved 																			 */
	__IO u32  CSS;				/*!< Offset: 0x070 Sthmidt set Register 										 (R/W) */ 
	__O  u32  CSC;				/*!< Offset: 0x074 Sthmidt Clear Register 									 (W)   */  
	u32  RESERVED4[226];	/*!< Offset: 0x078 Reserved 																			 */	
	__O u32  MASKL[256];	/*!< Offset: 0x400 - 0x7FC Lower byte Masked Access Register (R/W) */
	__O u32  MASKH[256];	/*!< Offset: 0x800 - 0xBFC Upper byte Masked Access Register (R/W) */
} GPIO_TypeDef;

/** @defgroup AFIO_TypeDef
* @{ 
*/
typedef struct
{   
  __IO u32  AFS0;	        /*!< Offset: 0x000 Alternate Function Set Register0 		(R/W) */
	__IO u32  AFS1;    	    /*!< Offset: 0x004 Alternate Function Set Register1 		(R/W) */
	__O  u32  AFC;    	    /*!< Offset: 0x008 Alternate Function Clear Register0  	(W) 	*/
	u32 RESERVED0[15];	    /*!< Offset: 0x00C Reserved 																	*/	
	__IO u32  ANAS;					/*!< Offset: 0x048 Analog function Set Register  				(R/W) */ 
	__O  u32  ANAC;					/*!< Offset: 0x04C Analog function Clear Register  			(W) 	*/ 
} AFIO_TypeDef;
	
/** @defgroup EXTI_TypeDef
* @{ 
*/
typedef struct
{   
	__IO u32  IES;     	/*!< Offset: 0x000 Interrupt Enable Set Register  	 (R/W) */ 
	__O  u32  IEC;    	/*!< Offset: 0x004 Interrupt Enable Clear Register   (W)   */ 
	__IO u32  ITS;      /*!< Offset: 0x008 Interrupt Type Set Register0  		 (R/W) */ 
	__O  u32  ITC;      /*!< Offset: 0x00C Interrupt Type Clear Register0    (W)   */ 
	__IO u32  ITDS;	    /*!< Offset: 0x010 Interrupt Type Set Register1  		 (R/W) */ 
	__O  u32  ITDC;	    /*!< Offset: 0x014 Interrupt Type Clear Register1  	 (W)	 */ 
	__IO u32  PTS;      /*!< Offset: 0x018 Interrupt Polarity Set Register   (R/W) */ 
	__O  u32  PTC;   	/*!< Offset: 0x01C Interrupt Polarity Clear Register 	 (W)   */ 
	__IO u32  IF;	    /*!< Offset: 0x020 Interrupt Status Register  				 (R/W) */
} EXTI_TypeDef;
	
/** @defgroup PWM_TypeDef
* @{ 
*/
typedef struct	
{
	__IO u32 SR;        /*!< Offset: 0x00 Interrupt status Register   					(R/W) */
	__IO u32 CR1;       /*!< Offset: 0x04 Control Register1            					(R/W) */
    __IO u32 MSCR;    /*!< Offset: 0x08 Master And Slave Mode Control Register(R/W) */
	__IO u32 ITARR;     /*!< Offset: 0x0C Interrupt Repeat Timers     					(R/W) */
	__IO u32 ITCNT;     /*!< Offset: 0x10 Interrupt Repeat Timers CNT 					(R/W) */
	__IO u32 PSC;       /*!< Offset: 0x14 Prescale Register           					(R/W) */
	u32  	RESERVED0;    /*!< Offset: 0x18 Reserved 																		*/
	__IO u32 CNT;       /*!< Offset: 0x1C Timer Counter Register      					(R/W) */
	__IO u32 CR2;       /*!< Offset: 0x20 Match Control Register2      					(R/W) */
	__IO u32 ARR;       /*!< Offset: 0x24 Auto Reload Register       						(R/W) */
	__IO u32 OCR1;      /*!< Offset: 0x28 Output Compare Register1       				(R/W) */	
	__IO u32 OCR2;      /*!< Offset: 0x2C Output Compare Register2      				(R/W) */
	__IO u32 OCR3;      /*!< Offset: 0x30 Output Compare Register3       				(R/W) */
	__IO u32 OCR4;      /*!< Offset: 0x34 Output Compare Register4       				(R/W) */
	__IO u32 CAPR1;     /*!< Offset: 0x38 Capture Control Register1    				  (R/W) */
    __IO u32 CAPR2;   /*!< Offset: 0x3C Capture Control Register2    				  (R/W) */
	__IO u32 ICR1;      /*!< Offset: 0x40 Capture Value Register1     					(R/W) */
	__IO u32 ICR2;      /*!< Offset: 0x44 Capture Value Register2     					(R/W) */
	__IO u32 ICR3;      /*!< Offset: 0x48 Capture Value Register3     					(R/W) */
	__IO u32 ICR4;      /*!< Offset: 0x4C Capture Value Register4     					(R/W) */	
	__IO u32 OCMR;      /*!< Offset: 0x50 Compare Output Register     					(R/W) */
	__IO u32 BDTR;      /*!< Offset: 0x54 Break And Dead Time Register         	(R/W) */
    __IO u32 CR3;     /*!< Offset: 0x58 Control Register3            					(R/W) */
    __IO u32 TDCR;    /*!< Offset: 0x5C Trigger DMA Control Register        	(R/W) */
    __IO u32 TACR;    /*!< Offset: 0x60 Trigger ADC Control Register        	(R/W) */
} PWM_TypeDef;

/** @defgroup TIMx_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 SR;       /*!< Offset:0x000 	TIM Status Register  		 (R/W) */
	__IO u32 CR1;      /*!< Offset:0x004 	TIM Control Register1    (R/W) */
	__IO u32 PSC;      /*!< Offset:0x008 	TIM Prescale Register    (R/W) */
	u32  	RESERVED0;   /*!< Offset:0x00C  Reserved 											 */
	__IO u32 CNT;      /*!< Offset:0x010 	TIM Counter Register     (R/W) */
	__IO u32 CR2;      /*!< Offset:0x014 	TIM Control Register2    (R/W) */
	__IO u32 ARR;      /*!< Offset:0x018 	TIM Auto Reload Register (R/W) */
} TIMx_TypeDef;

/** @defgroup WDG_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 RLR;   		/*!< Offset:0x000  WDG Reload register	 (R/W) */
	__I  u32 CNT; 			/*!< Offset:0x004  WDG COUNT register		 (R/W) */
	__IO u32 CR;    		/*!< Offset:0x008  WDG Control register	 (R/W) */
	__IO u32 KR;  			/*!< Offset:0x00C  WDG Key register	 	 	 (R/W) */
	__IO u32 SR;   			/*!< Offset:0x00C  WDG Status register	 (R/W) */
	u32 RESERVED0[251]; /*!< Offset:0x010  Reserved 									 */      
	__IO u32 LOCK;    	/*!< Offset:0x400  WDG Lock register	 	 (R/W) */		
} WDG_TypeDef;

/** @defgroup UART_TypeDef
* @{ 
*/
typedef struct	
{
	__IO u32 DR;     	 /*!< Offset: 0x000  UART Buffer Register 				   (R/W) */
	__IO u32 CR;		 	 /*!< Offset: 0x004  UART Control Register				   (R/W) */
	__IO u32 BRR;      /*!< Offset: 0x008  UART Baud Rate Register			   (R/W) */
	__IO u32 IE;    	 /*!< Offset: 0x00C  UART Interrupt Enable Register  (R/W) */
	__IO u32 SR;     	 /*!< Offset: 0x010  UART Status Register						 (R/W) */
	u32 RESERVED0;  	 /*!< Offset: 0x014  Reserved 						 								 */
	__IO u32 TO;   		 /*!< Offset: 0x018  UART Time Out Register  			   (R/W) */
	__IO u32 TXFR; 		 /*!< Offset: 0x01C  UART TX Buffer Reset Register    (WO) */
	__IO u32 RXFR;   	 /*!< Offset: 0x020  UART RX Buffer Reset Register    (WO) */
	__IO u32 IMCR;		 /*!< Offset: 0x028  UART Infrared Modulation Control Register (R/W) */	
	__IO u32 IMDCR;		 /*!< Offset: 0x02C  UART Infrared Modulation Duty Control Register (R/W) */
} UART_TypeDef;

/** @defgroup SPI_TypeDef
* @{ 
*/
typedef struct		
{
	__IO u32 CR1;      /*!< Offset:	0x000  SPI Control Register1 				    (R/W) */
	__IO u32 CR2;      /*!< Offset:	0x004  SPI Control Register2 				    (R/W) */
	__IO u32 DR;       /*!< Offset:	0x008  SPI Data Register 				   	    (R/W) */
	__IO u32 SR1;      /*!< Offset:	0x00C  SPI Status Register1 				    (R/W) */
	__IO u32 BR; 	   	 /*!< Offset:	0x010  SPI Clock Prescaler Register 	  (R/W) */
	__IO u32 IE;       /*!< Offset:	0x014  SPI Interrupt Enable Register  	(R/W) */
	__IO u32 SR2;      /*!< Offset:	0x018  SPI Status Register2 				   	(R/W) */
	u32 RESERVED0;	   /*!< Offset:	0x01C  Reserved 															*/
	__IO u32 IFC;      /*!< Offset:	0x020  SPI Interrupt Flag Clear Register(R/W) */
	__IO u32 DCR;      /*!< Offset:	0x024  SPI DMA Control Register 				(R/W) */
	__IO u32 CSS;      /*!< Offset:	0x028  SPI Chip-Select Control Register (R/W) */
} SPI_TypeDef;

/** @defgroup I2C_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR;		 		 /*!< Offset: 0x000 	I2C Control Register  	 		(R/W) */
	__I  u32 SR; 		  	 /*!< Offset: 0x004 	I2C Status Register  		 		(R/W) */
	__IO u32 DR;  	 		 /*!< Offset: 0x008 	I2C Data Register  		 	 		(R/W) */
	__IO u32 OAR;	 			 /*!< Offset: 0x00C 	I2C Own Address Register 		(R/W) */
	__IO u32 RESERVED0;  /*!< Offset: 0x010   Reserved 													*/
	__IO u32 RESERVED1;  /*!< Offset: 0x014   Reserved												  */
	__IO u32 CCR; 		 	 /*!< Offset: 0x018 	I2C Clear Controll Register (R/W) */
} I2C_TypeDef;

/** @defgroup ADC_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR1;       /*!< Offset: 0x000  ADC Control Register1 									(R/W) */
	__IO u32 CR2;       /*!< Offset: 0x004  ADC Control Register2 									(R/W) */
	__IO u32 SR;    		/*!< Offset: 0x008  ADC Status Register  										(R/W) */
	__IO u32 DR;    		/*!< Offset: 0x00C 	ADC data Register 											(R/W) */
	__IO u32 CCR;    		/*!< Offset: 0x010 	ADC Calibration Control Register 				(R/W) */
	__IO u32 SCHR1;			/*!< Offset: 0x014 	ADC Scan Channe1 Configuration Register (R/W) */
	__IO u32 SCHR2;			/*!< Offset: 0x018 	ADC Scan Channe2 Configuration Register (R/W) */
	__IO u32 SCHR3;			/*!< Offset: 0x01C 	ADC Scan Channe3 Configuration Register (R/W) */
	__IO u32 SCHR4;			/*!< Offset: 0x020 	ADC Scan Channe4 Configuration Register (R/W) */
} ADC_TypeDef;	

/** @defgroup CMP_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR1;       /*!< Offset: 0x000  CMP Control Register1  				 (R/W) */
		u32 RESERVED0[2]; /*!< Offset: 0x004  Reserved 														 */
	__IO u32 IE;        /*!< Offset: 0x00C  CMP Interrupt Enable Register  (R/W) */	
	__IO u32 SR;        /*!< Offset: 0x010  CMP Status Register 					 (R/W) */
	__IO u32 CR2;       /*!< Offset: 0x014  CMP Control Register2   			 (R/W) */
} CMP_TypeDef;

/** @defgroup OPA_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR;       /*!< Offset: 0x000  OPA Control Register  (R/W) */
} OPA_TypeDef;

/** @defgroup LDAC_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR;       /*!< Offset: 0x000  LDAC Control Register  (R/W) */
} LDAC_TypeDef;

/** @defgroup CRC_TypeDef
* @{ 
*/
typedef struct
{                                                                              
	__IO u32 CR;       /*!< Offset: 0x000  CRC Control Register     (R/W) */
	__IO u32 SEED;     /*!< Offset: 0x004  CRC Seed Register   		  (R/W) */
	__IO u32 POLY;     /*!< Offset: 0x008  CRC polynomial Register  (R/W) */
	__IO u32 DIN;      /*!< Offset: 0x00C  CRC Data INPUT Register  (R/W) */
	__IO u32 DOUT;     /*!< Offset: 0x010  CRC Data INPUT Register  (R/W) */
} CRC_TypeDef;

/** @defgroup PWR_TypeDef
* @{ 
*/
typedef struct 
{
	__IO u32 PVDR;		 /*!< Offset: 0x000  PWR Power Voltage Detect Control Register (R/W) */
} PWR_TypeDef;

/** @defgroup RCC_TypeDef
* @{ 
*/
typedef struct 
{
	__IO u32 HSECR1;  		/*!< Offset: 0x008 	 RCC HSE Control Register1 							(R/W) */
	__IO u32 HSECR2;  		/*!< Offset: 0x00C 	 RCC HSE Control Register2 							(R/W) */
	__IO u32 HSICR;				/*!< Offset: 0x010 	 RCC HSI Control Register  							(R/W) */
	__IO u32 LSICR;				/*!< Offset: 0x014 	 RCC LSI Control Register  							(R/W) */
	__IO u32 PCR;      		/*!< Offset: 0x018 	 RCC PLL Control Register  							(R/W) */
	u32 RESERVED0[2];  		/*!< Offset: 0x01C   Reserved 																		*/
	__IO u32 MCOR;				/*!< Offset: 0x024 	 RCC MCO Configuration Register   			(R/W) */
	u32 RESERVED1[30201];	/*!< Offset: 0x028   Reserved 																		*/
	__IO u32 CFGR;				/*!< Offset: 0x1F00C RCC Clock Configuration Register 			(R/W) */
	__IO u32 RSR;					/*!< Offset: 0x1F010 RCC Reset State Register  							(R/W) */
	__IO u32 ASFRR;				/*!< Offset: 0x1F014 RCC Advanced Software Control Register (R/W) */
	__IO u32 RCR;					/*!< Offset: 0x1F018 RCC Reset Control Register             (R/W) */
}RCC_TypeDef;

/** @defgroup IFMC_TypeDef
* @{ 
*/
typedef struct
{
	__IO u32 CR; 						/*!< Offset: 0x000   	IFMC Control Register 					(R/W) */
	__IO u32 SR;   					/*!< Offset: 0x004   	IFMC Status Register 		 				(R/W) */
	__IO u32 IE;  					/*!< Offset: 0x008   	IFMC Interrupt Enable Register  (R/W) */
	__IO u32 AR;    				/*!< Offset: 0x00C   	IFMC Address Register 					(R/W) */
	__IO u32 DR;  					/*!< Offset: 0x010   	IFMC Data Register   	 					(R/W) */
	u32  RESERVED0[5];	  	/*!< Offset: 0x014   	Reserved 															*/
	__IO u32 PSC;  					/*!< Offset: 0x028    IFMC Prescaler Register  				(R/W) */
	u32  RESERVED1[31733]; 	/*!< Offset: 0x02C    Reserved 								 							*/
	__IO u32 BSR;  					/*!< Offset: 0x1F000  BOOT Status Register  					(R/W) */
	__IO u32 IAPAR;  				/*!< Offset: 0x1F004  IAP Adress Register  						(R/W) */
	u32  RESERVED2[7];		  /*!< Offset: 0x1F008  Reserved 									 						*/
	__IO u32 RPSR;  				/*!< Offset: 0x1F024  Read Protection Status Register (R/W) */
} IFMC_TypeDef;	

/** @defgroup DMA_TypeDef
* @{ 
*/
typedef struct
{                                                                              
  __IO u32 CSBAR;     	/*!< Offset: 0x000  DMA CHx Source Base Address Register              (R/W) */
  __IO u32 CDBAR;       /*!< Offset: 0x004  DMA CHx Destination Dase Address Register         (R/W) */
  __IO u32 CNDTR;       /*!< Offset: 0x008  DMA CHx Number of Data to Transfer Register       (R/W) */
  __IO u32 CCR;         /*!< Offset: 0x00C  DMA CHx Control Register                          (R/W) */
  __IO u32 CCSAR;       /*!< Offset: 0x010  DMA CHx Current Data Source Address Register      (R/W) */
  __IO u32 CCDAR;       /*!< Offset: 0x014  DMA CHx Current Data Destination Address Register (R/W) */
  __IO u32 CCNTR;       /*!< Offset: 0x018  DMA CHx Residue Cnt Register                      (R/W) */
} DMA_TypeDef;

/** @defgroup DMACM_TypeDef
* @{ 
*/
typedef struct
{	                
  __IO u32 IER;         /*!< Offset: 0x080  DMA Interrupt Enable Register         (R/W) */
  __IO u32 ICR;         /*!< Offset: 0x084  DMA Flag Clear Register               (R/W) */
  __IO u32 SR;          /*!< Offset: 0x088  DMA Status Register                   (R/W) */
  __IO u32 CHCR;        /*!< Offset: 0x08C  DMA Relevance Peripheral Register     (R/W) */
} DMACM_TypeDef;

/** @defgroup CEEP_TypeDef
* @{ 
*/
typedef struct
{
  __IO u32 HCR;  					/*!< Offset:0x000   BEEP Drive Control Register  (R/W) */
	u32  RESERVED1[1015];		/*!< Offset:0x004   Reserved 													 */
	__IO u32 CR;    				/*!< Offset:0x2800  BEEP Control Register        (R/W) */
} BEEP_TypeDef;

/*Peripheral and SRAM base address */
#define SRAM_BASE             (0x20000000)     
#define FLASH_BASE            (0x00000000)     

#define APB_BASE              (0x40000000)
#define AHB_BASE              (0x48000000)

/* AHB peripherals */
#define GPIOA_BASE        (AHB_BASE + 0x00000000)
#define GPIOB_BASE        (AHB_BASE + 0x00001000)
#define GPIOC_BASE        (AHB_BASE + 0x00002000)
#define GPIOF_BASE        (AHB_BASE + 0x00003000)

#define EXTIA_BASE				(AHB_BASE + 0x0000001C)
#define EXTIB_BASE				(AHB_BASE + 0x0000101C)
#define EXTIC_BASE				(AHB_BASE + 0x0000201C)
#define EXTIF_BASE				(AHB_BASE + 0x0000301C)

#define AFIOA_BASE				(AHB_BASE + 0x00000010)
#define AFIOB_BASE				(AHB_BASE + 0x00001010)
#define AFIOC_BASE				(AHB_BASE + 0x00002010)
#define AFIOF_BASE				(AHB_BASE + 0x00003010)

/* APB peripherals */
#define IFMC_BASE    	    (APB_BASE + 0x00000000)
#define CMP0_BASE	        (APB_BASE + 0x00000800)
#define CMP1_BASE	        (APB_BASE + 0x00000C00)
#define CMP2_BASE	        (APB_BASE + 0x00002C00)

#define LDAC_BASE	      	(APB_BASE + 0x00001830)
#define TIM2_BASE       	(APB_BASE + 0x00001000)
#define TIM3_BASE       	(APB_BASE + 0x00001400)
#define RCC_BASE     	    (APB_BASE + 0x00001808)
#define PWR_BASE        	(APB_BASE + 0x00001800)
#define TIM4_BASE        	(APB_BASE + 0x00001C00)
#define BEEP_BASE         (APB_BASE + 0x00001820)
#define OPA_BASE	        (APB_BASE + 0x0000182C)

#define IWDG_BASE       	(APB_BASE + 0x00003000)
#define SPI1_BASE        	(APB_BASE + 0x00003800)
#define CRC_BASE         	(APB_BASE + 0x00003C00)
#define UART0_BASE    	  (APB_BASE + 0x00004400)
#define I2C0_BASE         (APB_BASE + 0x00005400)
#define I2C1_BASE         (APB_BASE + 0x00005800)
#define ADC_BASE          (APB_BASE + 0x00012400)
#define TIM1_BASE        	(APB_BASE + 0x00012C00)
#define SPI0_BASE         (APB_BASE + 0x00013000)
#define UART1_BASE   	  	(APB_BASE + 0x00013800)
#define ID_BASE		        (APB_BASE + 0x0001F020)
#define DMA0_BASE         (APB_BASE + 0x0000F000)
#define DMA1_BASE       	(APB_BASE + 0x0000F020)
#define DMACM_BASE       	(APB_BASE + 0x0000F080)
#define TIM5_BASE       	(APB_BASE + 0x00014400)
#define TIM6_BASE       	(APB_BASE + 0x00014800)
#define TIM7_BASE       	(APB_BASE + 0x00014C00)

/*Peripheral declaration */	
#define PWR		((PWR_TypeDef  	   *) PWR_BASE )
#define RCC		((RCC_TypeDef   	 *) RCC_BASE )
#define ID		((ID_TypeDef       *) ID_BASE )

#define GPIOA	((GPIO_TypeDef     *) GPIOA_BASE )
#define GPIOB	((GPIO_TypeDef     *) GPIOB_BASE )
#define GPIOC	((GPIO_TypeDef     *) GPIOC_BASE )
#define GPIOF	((GPIO_TypeDef     *) GPIOF_BASE )

#define AFIOA	((AFIO_TypeDef     *) AFIOA_BASE )
#define AFIOB	((AFIO_TypeDef     *) AFIOB_BASE )
#define AFIOC	((AFIO_TypeDef     *) AFIOC_BASE )
#define AFIOF	((AFIO_TypeDef     *) AFIOF_BASE )

#define EXTIA	((EXTI_TypeDef     *) EXTIA_BASE )
#define EXTIB	((EXTI_TypeDef     *) EXTIB_BASE )
#define EXTIC	((EXTI_TypeDef     *) EXTIC_BASE )
#define EXTIF	((EXTI_TypeDef     *) EXTIF_BASE )

#define UART0 ((UART_TypeDef     *) UART0_BASE )
#define UART1 ((UART_TypeDef     *) UART1_BASE )
#define IFMC	((IFMC_TypeDef     *) IFMC_BASE )
#define ADC   ((ADC_TypeDef      *) ADC_BASE )
#define I2C0	((I2C_TypeDef      *) I2C0_BASE )
#define I2C1	((I2C_TypeDef      *) I2C1_BASE )
#define SPI0  ((SPI_TypeDef      *) SPI0_BASE )
#define SPI1	((SPI_TypeDef      *) SPI1_BASE )
#define CMP0	((CMP_TypeDef   	 *) CMP0_BASE )
#define CMP1	((CMP_TypeDef   	 *) CMP1_BASE )
#define CMP2	((CMP_TypeDef   	 *) CMP2_BASE )
#define OPA		((OPA_TypeDef   	 *) OPA_BASE )
#define LDAC	((LDAC_TypeDef   	 *) LDAC_BASE )
#define TIM1	((PWM_TypeDef      *) TIM1_BASE )
#define TIM2	((TIMx_TypeDef     *) TIM2_BASE )
#define TIM3	((TIMx_TypeDef     *) TIM3_BASE )
#define TIM4	((TIMx_TypeDef     *) TIM4_BASE )
#define CRC		((CRC_TypeDef      *) CRC_BASE )
#define IWDG	((WDG_TypeDef      *) IWDG_BASE )
#define BEEP  ((BEEP_TypeDef     *) BEEP_BASE )
#define DMA0  ((DMA_TypeDef      *) DMA0_BASE )
#define DMA1  ((DMA_TypeDef      *) DMA1_BASE )
#define DMACM ((DMACM_TypeDef    *) DMACM_BASE )
#define TIM5	((PWM_TypeDef      *) TIM5_BASE )
#define TIM6	((PWM_TypeDef      *) TIM6_BASE )
#define TIM7	((PWM_TypeDef      *) TIM7_BASE )

/******************** Peripheral Registers Bits Definition ***********************/
/********************  Bits definition for RCC_HSECR1 register  ******************/
#define RCC_HSECR1_HSEEN            	((u32)0x00000001)        /*!< HSE enable */
#define RCC_HSECR1_AAC              	((u32)0x00000002)        /*!< Automatic amplitude control */
#define RCC_HSECR1_ECEN             	((u32)0x00000004)        /*!< External clock enable */
#define RCC_HSECR1_HSEFR            	((u32)0x00000010)        /*!< HSE frequency range */
#define RCC_HSECR1_LPF              	((u32)0x00000300)        /*!< Low pass filter */
#define RCC_HSECR1_LPFB             	((u32)0x00000400)        /*!< Low pass filter bypass */
#define RCC_HSECR1_HSERDY           	((u32)0x80000000)        /*!< HSE ready flag */

/********************  Bits definition for RCC_HSECR2 register  ******************/
#define RCC_HSECR2_CAD              	((u32)0x00000007)        /*!< Current adjust */
#define RCC_HSECR2_CS               	((u32)0x00000070)        /*!< Capacitance selection */
#define RCC_HSECR2_FDR              	((u32)0x00000300)        /*!< Feedback resistance selection */

/********************  Bits definition for RCC_HSI register  ******************/
#define RCC_HSICR_HSIEN             	((u32)0x00000001)        /*!< HSI enable */

/********************  Bits definition for RCC_LSICR register  ******************/
#define RCC_LSICR_LSIEN             	((u32)0x00000001)        /*!< LSI enable */

/********************  Bits definition for RCC_PCR register  ******************/
#define RCC_PCR_PLLEN               	((u32)0x00000001)        /*!< PLL enable */

/********************  Bits definition for RCC_MCOR register  ******************/
#define RCC_MCOR_COPRE              	((u32)0x00000007)        /*!< Clock output prescale */
#define RCC_MCOR_COSRC                ((u32)0x00000070)        /*!< Clock output source */

/********************  Bits definition for RCC_CFGR register  ******************/
#define RCC_CFGR_SCW                  ((u32)0x00000003)        /*!< System clock switch */
#define RCC_CFGR_HPRE                 ((u32)0x000001F0)        /*!< HCLK prescaler */
#define RCC_CFGR_PLLSRC               ((u32)0x00000C00)        /*!< PLL entry clock source */
#define RCC_CFGR_HSEDE                ((u32)0x00001000)        /*!< PLL fail detecting enable */
#define RCC_CFGR_HSEF                 ((u32)0x00002000)        /*!< HSE fail flag */
#define RCC_CFGR_PLLDE                ((u32)0x00004000)        /*!< PLL fail detecting enable */
#define RCC_CFGR_PLLF                 ((u32)0x00008000)        /*!< PLL fail flag */
#define RCC_CFGR_WKDL                 ((u32)0x00030000)        /*!< Wake up delay times */
#define RCC_CFGR_WKCK                 ((u32)0x00100000)        /*!< System clock after wakeup */
#define RCC_CFGR_PPRE                 ((u32)0x1F000000)        /*!< PCLK prescaler */

/********************  Bits definition for RCC_RSR register  ******************/
#define RCC_RSR_SFR                   ((u32)0x00000001)        /*!< Software reset */
#define RCC_RSR_IWDGR                 ((u32)0x00000002)        /*!< IWDG reset */
#define RCC_RSR_HSER                  ((u32)0x00000010)        /*!< HSE fail reset */
#define RCC_RSR_PLLR                  ((u32)0x00000020)        /*!< PLL fail reset */
#define RCC_RSR_POR                   ((u32)0x00000040)        /*!< Power reset */
#define RCC_RSR_PINR                  ((u32)0x00000080)        /*!< Pin reset */
#define RCC_RSR_PVDR                  ((u32)0x00000100)        /*!< PVD low voltage reset */

/********************  Bits definition for RCC_HSFRR register  ******************/
#define RCC_ASFRR_KEY                 ((u32)0x0000AB56)        /*!< Key */

/********************  Bits definition for RCC_RCR register  ******************/
#define RCC_RCR_HREN                  ((u32)0x00000010)        /*!< HSE fail reset enable */
#define RCC_RCR_PREN                  ((u32)0x00000020)        /*!< PLL fail reset enable */
#define RCC_RCR_PDRE                  ((u32)0x00000100)        /*!< PVD low voltage reset enable */
#define RCC_RCR_ASFREN                ((u32)0x00000400)        /*!< Advanced software reset enable */

/******************************************************************************/
/********************  Bits definition for PWR_PVDR register  ******************/
#define PWR_PVDR_PVDE                       ((u32)0x00000001)    /*!< Power voltage detection enable */
#define PWR_PVDR_PLS                        ((u32)0x0000000E)    /*!< Power level selection */

/******************************************************************************/
/*                                                                            */
/*                                      AFIO                                  */
/*                                                                            */
/******************************************************************************/
/****************** Bit definition for AFIO_AFS0 register  ********************/
#define AFIO_AFS0_IO0            ((u32)0x0000000F)              /*!<Port x pin 0 digtal alternate function  */
#define AFIO_AFS0_IO1            ((u32)0x000000F0)              /*!<Port x pin 1 digtal alternate function  */
#define AFIO_AFS0_IO2            ((u32)0x00000F00)              /*!<Port x pin 2 digtal alternate function  */
#define AFIO_AFS0_IO3            ((u32)0x0000F000)              /*!<Port x pin 3 digtal alternate function  */
#define AFIO_AFS0_IO4            ((u32)0x000F0000)              /*!<Port x pin 4 digtal alternate function  */
#define AFIO_AFS0_IO5            ((u32)0x00F00000)              /*!<Port x pin 5 digtal alternate function  */
#define AFIO_AFS0_IO6            ((u32)0x0F000000)              /*!<Port x pin 6 digtal alternate function  */
#define AFIO_AFS0_IO7            ((u32)0xF0000000)              /*!<Port x pin 7 digtal alternate function  */

/****************** Bit definition for AFIO_AFS1 register  ********************/
#define AFIO_AFS1_IO8             ((u32)0x0000000F)             /*!<Port x pin 8 digtal alternate function  */
#define AFIO_AFS1_IO9             ((u32)0x000000F0)             /*!<Port x pin 9 digtal alternate function  */
#define AFIO_AFS1_IO10            ((u32)0x00000F00)             /*!<Port x pin 10 digtal alternate function  */
#define AFIO_AFS1_IO11            ((u32)0x0000F000)             /*!<Port x pin 11 digtal alternate function  */
#define AFIO_AFS1_IO12            ((u32)0x000F0000)             /*!<Port x pin 12 digtal alternate function  */
#define AFIO_AFS1_IO13            ((u32)0x00F00000)             /*!<Port x pin 13 digtal alternate function  */
#define AFIO_AFS1_IO14            ((u32)0x0F000000)             /*!<Port x pin 14 digtal alternate function  */
#define AFIO_AFS1_IO15            ((u32)0xF0000000)             /*!<Port x pin 15 digtal alternate function  */

/******************************************************************************/
/*                                                                            */
/*                      IFMC Registers                      */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for IFMC_CR register  ******************/
#define  IFMC_CR_START   		      			((u32)0x00000001)        /*!< Start generation */
#define  IFMC_CR_CMD              			((u32)0x00000006)        /*!< IFMC operation command */
#define  IFMC_CR_ICE              			((u32)0x00000010)        /*!< Instruction cache enable */
#define  IFMC_CR_WAIT             			((u32)0x00000060)        /*!< Instruction fetch wait cycle */
#define  IFMC_CR_IPD             			  ((u32)0x00000080)        /*!< Instruction prefetch disable */
#define  IFMC_CR_MODE       	    			((u32)0x00000100)        /*!< IFMC operation mode */
#define  IFMC_CR_AINC             			((u32)0x00002000)        /*!< Address auto increment control */
#define  IFMC_CR_KEY             			  ((u32)0xFFFF0000)        /*!< IFMC key */
/*******************  Bit definition for IFMC_SR register  ******************/																																
#define  IFMC_SR_WC                     ((u32)0x00000001)        /*!< Write operation complete */
#define  IFMC_SR_PEC                    ((u32)0x00000002)        /*!< Page erase operation complete */
#define  IFMC_SR_CEC                    ((u32)0x00000004)        /*!< Chip erase operation complete */
#define  IFMC_SR_BSY                    ((u32)0x00000008)        /*!< Operation busy */
#define  IFMC_SR_CERR                   ((u32)0x00000010)        /*!< Operation command error */
#define  IFMC_SR_KERR                   ((u32)0x00000020)        /*!< Key error */
#define  IFMC_SR_AERR                   ((u32)0x00000040)        /*!< Address error */

/*******************  Bit definition for IFMC_IE register  ******************/																																
#define  IFMC_IE_WCIE                   ((u32)0x00000001)        /*!< Write operation complete interrupt enable */
#define  IFMC_IE_PECIE                  ((u32)0x00000002)        /*!< Page erase operation complete interrupt enable */
#define  IFMC_IE_CECIE                  ((u32)0x00000004)        /*!< Chip erase operation complete interrupt enable */
#define  IFMC_IE_CERIE                  ((u32)0x00000010)        /*!< Operation command error interrupt enable */
#define  IFMC_IE_KERIE                  ((u32)0x00000020)        /*!< Key error interrupt enable */
#define  IFMC_IE_AERIE                  ((u32)0x00000040)        /*!< Address error interrupt enable */

/*******************  Bit definition for IFMC_AR register  *******************/
#define  IFMC_AR_AR                     ((u32)0x0000FFFC)        /*!< IFMC words addr */

/*******************  Bit definition for IFMC_DR register  *******************/
#define  IFMC_DR_DR                     ((u32)0xFFFFFFFF)        /*!< IFMC data */

/*******************  Bit definition for IFMC_PSC register  *******************/
#define  IFMC_PSC_PSC                   ((u32)0x000000FF)        /*!< Prescaler value */

/********************  Bits definition for IFMC_BSR register  ******************/
#define  IFMC_BSR_IAPF                  ((u32)0x00000002)        /*!< IAP Enable Flag */

/********************  Bits definition for IFMC_IAPAR register  ******************/
#define  IFMC_IAPAR_AR                  ((u32)0x0000FE00)        /*!< IAP address */

/********************  Bits definition for IFMC_RPT register  ******************/
#define  IFMC_RPSR_PSR                 	((u32)0x00000001)        /*!< Data protection status */

/******************************************************************************/
/*                                                                            */
/*      Universal Asynchronous Receiver Transmitter (UART)      						  */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for UART_DR register  *******************/
#define  UART_DR                           ((u16)0x01FF)           /*!< Data Register */

/******************  Bit definition for UART_CR register  *******************/
#define  UART_CR_WP                        ((u32)0x00000007)       /*!< Word length and parity config */
#define  UART_CR_STOP                      ((u32)0x00000018)       /*!< Stop bit length */
#define  UART_CR_PS                        ((u32)0x00000020)       /*!< parity mode */
#define  UART_CR_LPB                       ((u32)0x00000040)       /*!< loopback mode */
#define  UART_CR_EN                        ((u32)0x00000080)       /*!< UART enable */
#define  UART_CR_RE                        ((u32)0x00000100)       /*!< Receiver enable */
#define  UART_CR_DMAE                      ((u32)0x00001000)       /*!< DMA mode enable */
#define  UART_CR_DMATC                     ((u32)0x00006000)       /*!< DMA trigger control */
#define  UART_CR_RXP                       ((u32)0x00010000)       /*!< Receiver polarity control */
#define  UART_CR_TXP                       ((u32)0x00020000)       /*!< Transmitter polarity control */
#define  UART_CR_SLME                      ((u32)0x00100000)       /*!< single-line mode enable */
#define  UART_CR_SLDS                      ((u32)0x00200000)       /*!< single-line direction setting */

/******************  Bit definition for UART_BRR register  *******************/
#define  UART_BRR_BR                       ((u32)0x0000FFFF)       /*!< Baud rate control */

/******************  Bit definition for UART_IE register  *******************/
#define  UART_IE_RXNEI                   ((u32)0x00000001)        /*!< Receive FIFO not empty interrupt enable */
#define  UART_IE_RXHFI                   ((u32)0x00000002)        /*!< Receive FIFO half full interrupt enable */
#define  UART_IE_RXFI                    ((u32)0x00000004)        /*!< Receive FIFO full interrupt enable */
#define  UART_IE_RXCOTI                  ((u32)0x00000008)        /*!< Receive FIFO clear overtime interrupt enable */
#define  UART_IE_IDLEI                   ((u32)0x00000010)        /*!< Idle overtime interrupt enable */
#define  UART_IE_PEI                     ((u32)0x00000020)        /*!< parity error interrupt enable */      
#define  UART_IE_FEI                     ((u32)0x00000040)        /*!< frame error interrupt enable */
#define  UART_IE_OVRI                    ((u32)0x00000080)        /*!< Receive FIFO overflow interrupt enable */    
#define  UART_IE_TXEI                    ((u32)0x00000100)        /*!< Transmit FIFO empty interrupt enable */         
#define  UART_IE_TXHEI                   ((u32)0x00000200)        /*!< Transmit FIFO half empty interrupt enable */       
#define  UART_IE_TXFI                    ((u32)0x00000400)        /*!< Transmit FIFO full interrupt enable */   
#define  UART_IE_TXOI                    ((u32)0x00000800)        /*!< Transmit end interrupt enable */  

/******************  Bit definition for UART_SR register  *******************/
#define  UART_SR_RXNE                     ((u32)0x00000001)        /*!< Receive FIFO not empty flag */
#define  UART_SR_RXHF                     ((u32)0x00000002)        /*!< Receive FIFO half full flag */
#define  UART_SR_RXF                      ((u32)0x00000004)        /*!< Receive FIFO full flag */
#define  UART_SR_RXCOT                    ((u32)0x00000008)        /*!< Receive FIFO clear overtime flag */
#define  UART_SR_IDLE                     ((u32)0x00000010)        /*!< Idle overtime interrupt enable */
#define  UART_SR_PE                       ((u32)0x00000020)        /*!< parity error flag */      
#define  UART_SR_FE                       ((u32)0x00000040)        /*!< frame error flag */
#define  UART_SR_OVR                      ((u32)0x00000080)        /*!< Receive FIFO overflow flag */    
#define  UART_SR_TXE                      ((u32)0x00000100)        /*!< Transmit FIFO empty flag */         
#define  UART_SR_TXHE                     ((u32)0x00000200)        /*!< Transmit FIFO half empty flag */       
#define  UART_SR_TXF                      ((u32)0x00000400)        /*!< Transmit FIFO full flag */   
#define  UART_SR_TXO                      ((u32)0x00000800)        /*!< Transmit end flag */  

/******************  Bit definition for UART_TO_TO register  *******************/
#define  UART_TO_TO                        ((u8)0xFF)             /*!< timeout*/

/******************  Bit definition for UART_TXFR register  *******************/
#define  UART_TXFR_TXFR                    ((u32)0xFFFFFFFF)      /*!< Transmit FIFO reset */

/******************  Bit definition for UART_RXFR register  *******************/
#define  UART_RXFR_RXFR                    ((u32)0xFFFFFFFF)      /*!< Receive FIFO reset */ 

/******************  Bit definition for UART_IRR register  *******************/
#define  UART_IMCR_IRE                       ((u32)0x00000001)    /*!<Infrared enable */
#define  UART_IMCR_IRPN                      ((u32)0x00000002)    /*!<Infrared polarity control */
#define  UART_IMCR_IRBD                      ((u32)0x00000030)    /*!<Infrared baud rate */

/******************  Bit definition for UART_IRTIM1C register  *******************/
#define  UART_IMDCR_DUTY               			 ((u32)0x00000FFF)    /*!< Infrared duty cycle */

/******************************************************************************/
/*                                                                            */
/*                      Analog to Digital Converter (ADC)                     */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for ADC_CR1 register  ******************/
#define ADC_CR1_EN                                ((u32)0x00000001)         /*!< ADC enable                              */
#define ADC_CR1_MODE                              ((u32)0x00000002)         /*!< ADC mode                                */
#define ADC_CR1_TRIGS                             ((u32)0x0000000C)         /*!< ADC trigger source selection            */
#define ADC_CR1_TIMS                              ((u32)0x000000F0)         /*!< ADC timer trigger source selection      */
#define ADC_CR1_TME                               ((u32)0x00000100)         /*!< ADC TRIM enable                         */
#define ADC_CR1_EOCIE                             ((u32)0x00000400)         /*!< ADC end of conversion interrupt enable  */
#define ADC_CR1_ALIGN                             ((u32)0x00000800)         /*!< ADC ALIGN               								 */
#define ADC_CR1_SOC                               ((u32)0x00001000)         /*!< ADC start on control                    */
#define ADC_CR1_CHS                               ((u32)0x001F0000)         /*!< ADC channel selection                   */
#define ADC_CR1_BGS                               ((u32)0x00200000)         /*!< ADC bg voltage selection                */
#define ADC_CR1_SCANE                             ((u32)0x00400000)         /*!< ADC scan enable                         */
#define ADC_CR1_EOSIE                             ((u32)0x00800000)         /*!< ADC end of scan interrupt enable        */
#define ADC_CR1_AVGE                              ((u32)0x02000000)         /*!< Average enable                          */
#define ADC_CR1_ADVRPS                            ((u32)0x04000000)         /*!< ADC voltage reference positive selection*/
#define ADC_CR1_DMAE                              ((u32)0x10000000)         /*!< ADC ADC DMA enable                      */
#define ADC_CR1_EXTS                              ((u32)0x20000000)         /*!< ADC external trigger source selection   */

/********************  Bits definition for ADC_CR2 register  ******************/
#define ADC_CR2_RDTC                              ((u32)0x000000FF)         /*!< ADC ready time control                   */
#define ADC_CR2_SMP                               ((u32)0x00007F00)         /*!< ADC sample time                          */
#define ADC_CR2_PSC                               ((u32)0x007F0000)         /*!< ADC prescaler                       			*/
#define ADC_CR2_AVGT                              ((u32)0x07000000)         /*!< Average times                       			*/

/********************  Bits definition for ADC_SR register  ******************/
#define ADC_SR_RDY                               ((u32)0x00000001)         /*!< ADC ready                     */
#define ADC_SR_EOC                               ((u32)0x00000002)         /*!< ADC end of conversion         */
#define ADC_SR_EOS                               ((u32)0x00000004)         /*!< ADC end of scan               */

/********************  Bits definition for ADC_DR register  ******************/
#define ADC_DR_DATA                              ((u32)0x0000FFFF)         /*!< ADC data                      */

/********************  Bits definition for ADC_CCR register  ******************/
#define ADC_CCR_TRIM                            ((u32)0x0000003F)         /*!< Trim value                 		 			 */
#define ADC_CCR_KEY                              ((u32)0x3BA60000)        /*!< ADC data correction value write key   */

/********************  Bits definition for ADC_SCHR1 register  ******************/
#define ADC_SCHR1_CH0                            ((u32)0x0000001F)         /*!< ADC scan channel 0 selection                  */
#define ADC_SCHR1_CH1                            ((u32)0x000003E0)         /*!< ADC scan channel 1 selection                  */
#define ADC_SCHR1_CH2                            ((u32)0x00007C00)         /*!< ADC scan channel 2 selection                  */
#define ADC_SCHR1_CH3                            ((u32)0x000F8000)         /*!< ADC scan channel 3 selection                  */
#define ADC_SCHR1_CH4                            ((u32)0x01F00000)         /*!< ADC scan channel 4 selection                  */
#define ADC_SCHR1_CH5                            ((u32)0x3E000000)         /*!< ADC scan channel 5 selection                  */

/********************  Bits definition for ADC_SCHR2 register  ******************/
#define ADC_SCHR2_CH6                            ((u32)0x0000001F)         /*!< ADC scan channel 6 selection                  */
#define ADC_SCHR2_CH7                            ((u32)0x000003E0)         /*!< ADC scan channel 7 selection                  */
#define ADC_SCHR2_CH8                            ((u32)0x00007C00)         /*!< ADC scan channel 8 selection                  */
#define ADC_SCHR2_CH9                            ((u32)0x000F8000)         /*!< ADC scan channel 9 selection                  */
#define ADC_SCHR2_CH10                           ((u32)0x01F00000)         /*!< ADC scan channel 10 selection                 */
#define ADC_SCHR2_CH11                           ((u32)0x3E000000)         /*!< ADC scan channel 11 selection                 */

/********************  Bits definition for ADC_SCHR3 register  ******************/
#define ADC_SCHR3_CH12                           ((u32)0x0000001F)         /*!< ADC scan channel 12 selection                 */
#define ADC_SCHR3_CH13                           ((u32)0x000003E0)         /*!< ADC scan channel 13 selection                 */
#define ADC_SCHR3_CH14                           ((u32)0x00007C00)         /*!< ADC scan channel 14 selection                 */
#define ADC_SCHR3_CH15                           ((u32)0x000F8000)         /*!< ADC scan channel 15 selection                 */
#define ADC_SCHR3_CH16                           ((u32)0x01F00000)         /*!< ADC scan channel 16 selection                 */
#define ADC_SCHR3_CH17                           ((u32)0x3E000000)         /*!< ADC scan channel 17 selection                 */

/********************  Bits definition for ADC_SCHR4 register  ******************/
#define ADC_SCHR4_CH18                           ((u32)0x0000001F)         /*!< ADC scan channel 18 selection                 */
#define ADC_SCHR4_CH19                           ((u32)0x000003E0)         /*!< ADC scan channel 19 selection                 */
#define ADC_SCHR4_CNT                            ((u32)0x001F0000)         /*!< ADC scan channel number configuration         */

/******************************************************************************/
/*                                                                            */
/*                   Inter-integrated Circuit Interface (I2C0)                 */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for I2C_CR register  *******************/
#define  I2C_CR_ACK                         ((u32)0x00000004)        /*!< Acknowledge enable */ 
#define  I2C_CR_SI                          ((u32)0x00000008)        /*!< I2C status flag */
#define  I2C_CR_STOP                        ((u32)0x00000010)        /*!< Stop generation */
#define  I2C_CR_STAR                        ((u32)0x00000020)        /*!< Start generation */
#define  I2C_CR_EN                          ((u32)0x00000040)        /*!< I2C enable */
#define  I2C_CR_HCT                         ((u32)0x0000FF00)        /*!< High level detection coefficient of time) */
#define  I2C_CR_PSC                         ((u32)0x03FF0000)        /*!< Prescaler */

/*******************  Bit definition for I2C_SR register  *******************/
#define  I2C_SR_SR                          ((u32)0x000000F8)      	 /*!< I2C bus status */

/*******************  Bit definition for I2C_DR register  *******************/
#define  I2C_DR_DR                          ((u32)0x000000FF)        /*!< I2C data */

/*******************  Bit definition for I2C_OAR register  *******************/
#define  I2C_OAR_BC													((u32)0x00000001)        /*!< Broadcast response control */    
#define  I2C_OAR_ADDR                       ((u32)0x000000FE)        /*!< I2C addr */

/*******************  Bit definition for I2C_CCR register  *******************/
#define  I2C_CCR_ACK                        ((u32)0x00000004)        /*!< Clear Acknowledge control) */
#define  I2C_CCR_SI                         ((u32)0x00000008)        /*!< Clear I2C interrupt flag */
#define  I2C_CCR_STOP                       ((u32)0x00000010)        /*!< Clear stop generation */
#define  I2C_CCR_STAR                       ((u32)0x00000020)        /*!< Clear start generation */
#define  I2C_CCR_EN                         ((u32)0x00000040)        /*!< I2C disable */
#define  I2C_CCR_HCT                        ((u32)0x0000FF00)        /*!< Clear high level detection time */
#define  I2C_CCR_PSC                        ((u32)0x03FF0000)        /*!< Clear prescaler */

/******************************************************************************/
/*                                                                            */
/*                        Serial Peripheral Interface (SPI)                   */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for SPI_CR1 register  ********************/
#define  SPI_CR1_DFF                        ((u32)0x0000000F)         /* SPI_data_size */
#define  SPI_CR1_CPOL		                		((u32)0x00000040)         /* Clock Polarity */
#define  SPI_CR1_CPHA		                		((u32)0x00000080)         /* Clock Phase */
#define  SPI_CR1_PSC                        ((u32)0x0000FF00)         /* Post-division factor */

/*******************  Bit definition for SPI_CR2 register  ********************/
#define  SPI_CR2_LBM				                ((u32)0x00000001)         /* Loopback Mode */
#define  SPI_CR2_EN				                  ((u32)0x00000002)         /* SPI ENABLE*/
#define  SPI_CR2_MSM			                  ((u32)0x00000004)         /* Master-slave selection */
#define  SPI_CR2_SOD			                  ((u32)0x00000008)         /* Master-slave selection */

/********************  Bit definition for SPI_DR register  ********************/
#define  SPI_DR_DR                          ((u16)0xFFFF)             /* Data Register */

/********************  Bit definition for SPI_SR1 register  ********************/
#define  SPI_SR1_TXE                        ((u32)0x00000001)         /* Transmission FIFO is empty */
#define  SPI_SR1_TNF                        ((u32)0x00000002)         /* Transmission FIFO is not empty */
#define  SPI_SR1_RXNE                       ((u32)0x00000004)         /* Receiver FIFO is not empty */
#define  SPI_SR1_RXF                        ((u32)0x00000008)         /* Receiver FIFO is Full */
#define  SPI_SR1_BSY                        ((u32)0x00000010)         /* Transmission module is busy */	

/********************  Bit definition for SPI_BR register  ********************/
#define  SPI_BR_BR                          ((u32)0x000000FF)         /* Prescaler factor */

/********************  Bit definition for SPI_IE register  ********************/
#define  SPI_IE_OVRE                        ((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_IE_OTE                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */
#define  SPI_IE_RXHE                        ((u32)0x00000004)         /* Receiver FIFO Half-full */
#define  SPI_IE_TXHE                        ((u32)0x00000008)         /* Transmission FIFO Half-full */

/********************  Bit definition for SPI_SR2 register  ********************/
#define  SPI_SR2_OVR                        ((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_SR2_OT                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */
#define  SPI_SR2_RXH                        ((u32)0x00000004)         /* Receiver FIFO Half-full */
#define  SPI_SR2_TXH                        ((u32)0x00000008)         /* Transmission FIFO Half-full */

/********************  Bit definition for SPI_IFC register  ********************/
#define  SPI_IFC_OVR                       	((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_IFC_OT                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */

/*******************  Bit definition for SPI_DCR register  ********************/
#define  SPI_DCR_RXDMAE				       				((u32)0x00000001)         /* Rx DMA request enable*/
#define  SPI_DCR_TXDMAE				        			((u32)0x00000002)         /* Tx DMA request enable*/
#define  SPI_DCR_DMATC			            		((u32)0x00000004)         /* DMA burst transfer enable*/

/********************  Bit definition for SPI_ChipSelectSignal register  ********************/
#define  SPI_CSS_CSS												((u32)0x00000004)         /* CS is controlled by software  */
#define  SPI_CSS_SWCS			    							((u32)0x00000008)         /* CS Set Bit by software  */

/******************************************************************************/
/*                                                                            */
/*                       Comparators (CMP)                  									*/
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for CMP_CR1 register  ********************/
#define  CMP_CR1_EN                   ((u32)0x00000001)         /*!< Comparator enable */
#define  CMP_CR1_CRS                  ((u32)0x00000002)         /*!< Comparator result */
#define  CMP_CR1_CNS                  ((u32)0x0000000C) 				/*!< Comparator negative intput selection */
#define  CMP_CR1_DFC                  ((u32)0x00000070)         /*!< Digital filter configuration */
#define  CMP_CR1_CPMS                 ((u32)0x00000080)        	/*!< Comparator power mode selection */
#define  CMP_CR1_OPC                  ((u32)0x00000100)        	/*!< Comparator output polarity selection */
#define  CMP_CR1_HYS                  ((u32)0x00000200)					/*!< Comparator hysteresis control */
#define  CMP_CR1_CPS                  ((u32)0x00003000)        	/*!< Comparator positive input selection */
#define  CMP_CR1_SYNC                 ((u32)0x00010000)					/*!< Comparator output synchronization control */
#define  CMP_CR1_PPC                  ((u32)0x00020000)					/*!< Comparator output PWM polarity control */
#define  CMP_CR1_PWMS                 ((u32)0x00700000)					/*!< Comparator output PWM selection */

/********************  Bit definition for CMP_IE register  ********************/
#define  CMP_IE_COF                   ((u32)0x00000001)         /*!< Comparator output falling edge interrupt enable */
#define  CMP_IE_COR                   ((u32)0x00000002)         /*!< Comparator output rising edge interrupt enable */
#define  CMP_IE_COFW                  ((u32)0x00000004)         /*!< Comparator output falling edge wake up interrupt enable */
#define  CMP_IE_CORW                  ((u32)0x00000008)         /*!< Comparator output rising edge wake up interrupt enable */

/********************  Bit definition for CMP_SR register  ********************/
#define  CMP_SR_COF                   ((u32)0x00000001)         /*!< Comparator output falling edge flag */
#define  CMP_SR_COR                   ((u32)0x00000002)         /*!< Comparator output rising edge flag */
#define  CMP_SR_COFW                  ((u32)0x00000004)         /*!< Comparator output falling edge wake up flag */
#define  CMP_SR_CORW                  ((u32)0x00000008)         /*!< Comparator output rising edge wake up flag */

/********************  Bit definition for CMP_CR2 register  ********************/
#define  CMP_CR2_DELAY	              ((u32)0x000003FF)         /*!< Comparator Initialization delay time */

/******************************************************************************/
/*                                                                            */
/*                                  LDAC                                			*/
/*                                                                            */
/******************************************************************************/
#define  LDAC_CR_DATA								 ((u32)0x0000001F)					/*!< LDAC data */
#define  LDAC_CR_EN									 ((u32)0x00000100)					/*!< LDAC enable */

/******************************************************************************/
/*                                                                            */
/*                       						opamp (OPA)                  						  */
/*                                                                            */
/******************************************************************************/
#define  OPA_CR_OPA0E									((u32)0x00000001)           /*!< Opamp0 enable */
#define  OPA_CR_OPA1E									((u32)0x00000002)           /*!< Opamp1 enable */

/******************************************************************************/
/*                                                                            */
/*                              TIM Registers                                 */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for TIM_SR register  *******************/  
#define  TIM_SR_ARF                        ((u32)0x00000001)       /*!< Auto reload flag */

/*******************  Bit definition for TIM_CR1 register  *******************/  
#define  TIM_CR1_EN                        ((u32)0x00000001)       /*!< Counter enable    */
#define  TIM_CR1_DBGE                      ((u32)0x00000100)       /*!< Counter enable    */

/*******************  Bit definition for TIM_PSC register  *******************/  
#define  TIM_PSC                           ((u16)0x0000FFFF)       /*!< Prescaler value   */

/*******************  Bit definition for TIM_CNT register  *******************/  
#define  TIM_CNT                           ((u16)0x0000FFFF)       /*!< Counter value     */

/*******************  Bit definition for TIM_CR2 register  *******************/  
#define  TIM_CR2_ARI                       ((u32)0x00000001)       /*!< Auto reload interrupt enable */
#define  TIM_CR2_RSTC                      ((u32)0x00000002)       /*!< Reset counter */ 
#define  TIM_CR2_OPM                       ((u32)0x00000004)       /*!< One-pulse mode */
#define  TIM_CR2_DIR                       ((u32)0x00000008)       /*!< Direction */  

/*******************  Bit definition for TIM1_ARR register  *******************/  
#define  TIM_ARR                           ((u16)0x0000FFFF)       /*!< Auto reload value */

/******************************************************************************/
/*                                                                            */
/*                      PWM  Registers                                  */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for PWM_SR register  *******************/  
#define  PWM_SR_ARF                      ((u32)0x00000001)       /*!< auto reload flag */
#define  PWM_SR_OC1F                     ((u32)0x00000002)       /*!< output compare 1 flag */
#define  PWM_SR_OC2F                     ((u32)0x00000004)       /*!< output compare 2 flag */
#define  PWM_SR_OC3F                     ((u32)0x00000008)       /*!< output compare 3 flag */
#define  PWM_SR_OC4F                     ((u32)0x00000010)       /*!< output compare 4 flag */
#define  PWM_SR_IC1R                     ((u32)0x00000020)       /*!< input capture 1 rising edge flag */
#define  PWM_SR_IC1F                     ((u32)0x00000040)       /*!< input capture 1 falling edge flag */
#define  PWM_SR_IC2R                     ((u32)0x00000080)       /*!< input capture 2 rising edge flag */
#define  PWM_SR_IC2F                     ((u32)0x00000100)       /*!< input capture 2 falling edge flag */
#define  PWM_SR_IC3R                     ((u32)0x00000200)       /*!< input capture 3 rising edge flag */
#define  PWM_SR_IC3F                     ((u32)0x00000400)       /*!< input capture 3 falling edge flag */
#define  PWM_SR_IC4R                     ((u32)0x00000800)       /*!< input capture 4 rising edge flag */
#define  PWM_SR_IC4F                     ((u32)0x00001000)       /*!< input capture 4 falling edge flag */
#define  PWM_SR_BIF                      ((u32)0x00002000)       /*!< Break input flag */
#define  PWM_SR_TIF                      ((u32)0x00004000)       /*!< Trigger input flag */
#define  PWM_SR_UF                       ((u32)0x00008000)       /*!< update flag */

/*******************  Bit definition for PWM_CR1 register  *******************/  
#define  PWM_CR1_EN                      ((u32)0x00000001)       /*!< Counter enable        								*/
#define  PWM_CR1_UG                      ((u32)0x00000002)       /*!< Update generation            				  */
#define  PWM_CR1_CLKS                    ((u32)0x00000004)       /*!< TIM internal clock source selection   */
#define  PWM_CR1_SAMPSC                  ((u32)0x00000070)       /*!< Sampling clock division       			  */
#define  PWM_CR1_DBGE                    ((u32)0x00000100)       /*!< TIM debug    												  */
#define  PWM_CR1_DIR                     ((u32)0x00000200)       /*!< Direction             								*/
#define  PWM_CR1_CMS                     ((u32)0x00000400)       /*!< Center-aligned mode selection   		  */
#define  PWM_CR1_CPC                     ((u32)0x00000800)       /*!< Compare preloaded control          		*/

/*******************  Bit definition for PWM_MSCR register  *******************/  
#define  PWM_MSCR_TIS                    ((u32)0x0000000F)       /*!< Trigger input selection          */
#define  PWM_MSCR_SMS                    ((u32)0x00000070)       /*!< Slave mode selection             */
#define  PWM_MSCR_TIE                    ((u32)0x00000080)       /*!< Trigger interrupt enable  			 */
#define  PWM_MSCR_ETF                    ((u32)0x00000700)       /*!< External trigger filter          */
#define  PWM_MSCR_ETPSC                  ((u32)0x00003000)       /*!< External trigger prescaler       */
#define  PWM_MSCR_ECE                    ((u32)0x00004000)       /*!< External clock enable            */
#define  PWM_MSCR_ETP                    ((u32)0x00008000)       /*!< External trigger polarity        */
#define  PWM_MSCR_TOS                    ((u32)0x000F0000)       /*!< Trigger output selection         */
#define  PWM_MSCR_SYNC                   ((u32)0x00100000)       /*!< TIM synchronization enable       */

/*******************  Bit definition for PWM_ITARR register  *******************/  
#define  PWM_ITARR                       ((u8)0xF)                /*!< TIM interrupt auto reload   */

/*******************  Bit definition for PWM_ITCNT register  *******************/  
#define  PWM_ITCNT                       ((u8)0xF)                /*!< TIM interrupt counter value   */

/*******************  Bit definition for PWM_PSC register  *******************/  
#define  PWM_PSC                         ((u16)0xFFFF)            /*!< Prescaler value   */

/*******************  Bit definition for PWM_CNT register  *******************/  
#define  PWM_CNT                         ((u16)0xFFFF)            /*!< Counter value   */

/*******************  Bit definition for PWM_CR2 register  *******************/  
#define  PWM_CR2_ARI                      ((u32)0x00000001)       /*!< Auto reload interrupt enable        */
#define  PWM_CR2_OC1I                     ((u32)0x00000002)       /*!< output compare 1 interrupt enable        */
#define  PWM_CR2_OC2I                     ((u32)0x00000004)       /*!< output compare 2 interrupt enable        */
#define  PWM_CR2_OC3I                     ((u32)0x00000008)       /*!< output compare 3 interrupt enable        */
#define  PWM_CR2_OC4I                     ((u32)0x00000010)       /*!< output compare 4 interrupt enable        */
#define  PWM_CR2_OPM                      ((u32)0x00000020)       /*!< One-pulse mode                           */
#define  PWM_CR2_UIE                      ((u32)0x00000040)       /*!< update interrupt enable                  */

/*******************  Bit definition for PWM_ARR register  *******************/  
#define  PWM_ARR                          ((u16)0xFFFF)            /*!< Auto reload value             */

/*******************  Bit definition for PWM_OCR1 register  *******************/  
#define  PWM_OCR1                         ((u16)0xFFFF)            /*!< output compare 1 value           */

/*******************  Bit definition for PWM_OCR2 register  *******************/  
#define  PWM_OCR2                         ((u16)0xFFFF)            /*!< output compare 2 value           */

/*******************  Bit definition for PWM_OCR3 register  *******************/  
#define  PWM_OCR3                         ((u16)0xFFFF)            /*!< output compare 3 value           */

/*******************  Bit definition for PWM_OCR4 register  *******************/  
#define  PWM_OCR4                         ((u16)0xFFFF)            /*!< output compare 4 value           */

/*******************  Bit definition for PWM_CAPR1 register  *******************/  
#define  PWM_CAPR1_IC1R                    ((u32)0x00000001)       /*!< input capture 1 rising capture enable          */
#define  PWM_CAPR1_IC1F                    ((u32)0x00000002)       /*!< input capture 1 falling capture enable          */
#define  PWM_CAPR1_IC1RC                   ((u32)0x00000004)       /*!< input capture 1 capture reset counter enable    */
#define  PWM_CAPR1_IC1I                    ((u32)0x00000008)       /*!< input capture 1 interrupt enable          */
#define  PWM_CAPR1_IC2R                    ((u32)0x00000010)       /*!< input capture 2 rising capture enable          */
#define  PWM_CAPR1_IC2F                    ((u32)0x00000020)       /*!< input capture 2 falling capture enable          */
#define  PWM_CAPR1_IC2RC                   ((u32)0x00000040)       /*!< input capture 2 capture reset counter enable    */
#define  PWM_CAPR1_IC2I                    ((u32)0x00000080)       /*!< input capture 2 interrupt enable          */
#define  PWM_CAPR1_IC3R                    ((u32)0x00000100)       /*!< input capture 3 rising capture enable          */
#define  PWM_CAPR1_IC3F                    ((u32)0x00000200)       /*!< input capture 3 falling capture enable          */
#define  PWM_CAPR1_IC3RC                   ((u32)0x00000400)       /*!< input capture 3 capture reset counter enable    */
#define  PWM_CAPR1_IC3I                    ((u32)0x00000800)       /*!< input capture 3 interrupt enable          */
#define  PWM_CAPR1_IC4R                    ((u32)0x00001000)       /*!< input capture 4 rising capture enable          */
#define  PWM_CAPR1_IC4F                    ((u32)0x00002000)       /*!< input capture 4 falling capture enable          */
#define  PWM_CAPR1_IC4RC                   ((u32)0x00004000)       /*!< input capture 4 capture reset counter enable    */
#define  PWM_CAPR1_IC4I                    ((u32)0x00008000)       /*!< input capture 4 interrupt enable          */
#define  PWM_CAPR1_IC1S                    ((u32)0x00070000)       /*!< input capture 1 source selection                 */
#define  PWM_CAPR1_ICS1S                   ((u32)0x00080000)       /*!< ICS1 selection                              */
#define  PWM_CAPR1_IC2S                    ((u32)0x00700000)       /*!< input capture 2 source selection                  */
#define  PWM_CAPR1_IC3S                    ((u32)0x07000000)       /*!< input capture 3 source selection                  */
#define  PWM_CAPR1_IC4S                    ((u32)0x70000000)       /*!< input capture 4 source selection                  */

/*******************  Bit definition for PWM_CAPR2 register  *******************/  
#define  PWM_CAPR2_IC1FR                   ((u32)0x00000007)       /*!< Input capture 1 filter                      */
#define  PWM_CAPR2_IC1PSC                  ((u32)0x00000030)       /*!< Input capture 1 prescaler                    */
#define  PWM_CAPR2_IC2FR                   ((u32)0x00000700)       /*!< Input capture 2 filter                      */
#define  PWM_CAPR2_IC2PSC                  ((u32)0x00003000)       /*!< Input capture 2 prescaler                    */
#define  PWM_CAPR2_IC3FR                   ((u32)0x00070000)       /*!< Input capture 3 filter                      */
#define  PWM_CAPR2_IC3PSC                  ((u32)0x00300000)       /*!< Input capture 3 prescaler                    */
#define  PWM_CAPR2_IC4FR                   ((u32)0x07000000)       /*!< Input capture 4 filter                      */
#define  PWM_CAPR2_IC4PSC                  ((u32)0x30000000)       /*!< Input capture 4 prescaler                    */

/*******************  Bit definition for PWM_ICR1 register  *******************/  
#define  PWM_ICR1                       ((u32)0x0000FFFF)       /*!< input capture 1 value   */

/*******************  Bit definition for PWM_ICR2 register  *******************/ 
#define  PWM_ICR2                       ((u32)0x0000FFFF)       /*!< input capture 2 value   */

/*******************  Bit definition for PWM_ICR3 register  *******************/  
#define  PWM_ICR3                       ((u32)0x0000FFFF)       /*!< input capture 3 value   */

/*******************  Bit definition for PWM_ICR4 register  *******************/  
#define  PWM_ICR4                       ((u32)0x0000FFFF)       /*!< input capture 4 value   */

/*******************  Bit definition for PWM_OCMR register  *******************/  
#define  PWM_OCMR_OC1M                       ((u32)0x00000007)       /*!< output compare 1 mode    */
#define  PWM_OCMR_OC1CE                      ((u32)0x00000008)       /*!< output compare 1 clear enable    */
#define  PWM_OCMR_OC2M                       ((u32)0x00000070)       /*!< output compare 2 mode    */
#define  PWM_OCMR_OC2CE                      ((u32)0x00000080)       /*!< output compare 2 clear enable    */
#define  PWM_OCMR_OC3M                       ((u32)0x00000700)       /*!< output compare 3 mode    */
#define  PWM_OCMR_OC3CE                      ((u32)0x00000800)       /*!< output compare 3 clear enable    */
#define  PWM_OCMR_OC4M                       ((u32)0x00007000)       /*!< output compare 4 mode    */
#define  PWM_OCMR_OC4CE                      ((u32)0x00008000)       /*!< output compare 4 clear enable    */
#define  PWM_OCMR_OIS1              				 ((u32)0x00010000)       /*!< Output Idle state 1            */
#define  PWM_OCMR_OIS2                 	     ((u32)0x00020000)       /*!< Output Idle state 2            */
#define  PWM_OCMR_OIS3                 	     ((u32)0x00040000)       /*!< Output Idle state 3            */
#define  PWM_OCMR_OIS4                       ((u32)0x00080000)       /*!< Output Idle state 4            */
#define  PWM_OCMR_OIS1N           			 		 ((u32)0x00100000)       /*!< Output Idle state 1 complementary        */
#define  PWM_OCMR_OIS2N             				 ((u32)0x00200000)       /*!< Output Idle state 2 complementary        */
#define  PWM_OCMR_OIS3N             		 		 ((u32)0x00400000)       /*!< Output Idle state 3 complementary        */
#define  PWM_OCMR_OIS4N             				 ((u32)0x00800000)       /*!< Output Idle state 4 complementary        */
#define  PWM_OCMR_OC1NE             				 ((u32)0x01000000)       /*!< Compare output 1 complementary output enable    */
#define  PWM_OCMR_OC2NE              				 ((u32)0x02000000)       /*!< Compare output 2 complementary output enable    */
#define  PWM_OCMR_OC3NE               		 	 ((u32)0x04000000)       /*!< Compare output 3 complementary output enable    */
#define  PWM_OCMR_OC4NE              		 		 ((u32)0x08000000)       /*!< Compare output 4 complementary output enable    */
#define  PWM_OCMR_OC1E             		     	 ((u32)0x10000000)       /*!< Compare output 1 output enable        */
#define  PWM_OCMR_OC2E              		 		 ((u32)0x20000000)       /*!< Compare output 2 output enable        */
#define  PWM_OCMR_OC3E               		 		 ((u32)0x40000000)       /*!< Compare output 3 output enable        */
#define  PWM_OCMR_OC4E              		 		 ((u32)0x80000000)       /*!< Compare output 4 output enable        */

/*******************  Bit definition for PWM_BDTR register  *******************/  
#define  PWM_BDTR_DT                         ((u32)0x00000FFF)       /*!< Dead-time value             */
#define  PWM_BDTR_BKE                        ((u32)0x00010000)       /*!< Break enable             */
#define  PWM_BDTR_BKP                        ((u32)0x00020000)       /*!< Break polarity             */
#define  PWM_BDTR_BKI                        ((u32)0x00040000)       /*!< Break interrupt enable                 */
#define  PWM_BDTR_BKSC                       ((u32)0x00080000)       /*!< Break software control enable           */
#define  PWM_BDTR_BKIS                       ((u32)0x00F00000)       /*!< TIM break source selection         */
#define  PWM_BDTR_BKIC                       ((u32)0x01000000)       /*!< break input control   */

/*******************  Bit definition for PWM_CR3 register  *******************/  
#define  PWM_CR3_CC1P                      ((u32)0x00000001)       /*!< Capture/Compare 1 output polarity         */
#define  PWM_CR3_C1NP                      ((u32)0x00000002)       /*!< Compare 1 complementary output polarity          */
#define  PWM_CR3_CC2P                      ((u32)0x00000010)       /*!< Capture/Compare 2 output polarity         */
#define  PWM_CR3_C2NP                      ((u32)0x00000020)       /*!< Compare 2 complementary output polarity          */
#define  PWM_CR3_CC3P                      ((u32)0x00000100)       /*!< Capture/Compare 3 output polarity         */
#define  PWM_CR3_C3NP                      ((u32)0x00000200)       /*!< Compare 3 complementary output polarity          */
#define  PWM_CR3_CC4P                      ((u32)0x00001000)       /*!< Capture/Compare 4 output polarity         */
#define  PWM_CR3_C4NP                      ((u32)0x00002000)       /*!< Compare 4 complementary output polarity          */

/*******************  Bit definition for PWM_TDCR register  *******************/  
#define  PWM_TDCR_ARDE                     ((u32)0x00000001)       /*!< auto reload DMA request enable        */
#define  PWM_TDCR_OC1DE                    ((u32)0x00000002)       /*!< output compare 1 DMA request enable      */
#define  PWM_TDCR_OC2DE                    ((u32)0x00000004)       /*!< output compare 2 DMA request enable      */
#define  PWM_TDCR_OC3DE                    ((u32)0x00000008)       /*!< output compare 3 DMA request enable      */
#define  PWM_TDCR_OC4DE                    ((u32)0x00000010)       /*!< output compare 4 DMA request enable      */
#define  PWM_TDCR_IC1RDE                   ((u32)0x00000020)       /*!< input capture 1 rising edge DMA request enable */
#define  PWM_TDCR_IC1FDE                   ((u32)0x00000040)       /*!< input capture 1 falling edge DMA request enable */
#define  PWM_TDCR_IC2RDE                   ((u32)0x00000080)       /*!< input capture 2 rising edge DMA request enable */
#define  PWM_TDCR_IC2FDE                   ((u32)0x00000100)       /*!< input capture 2 falling edge DMA request enable */
#define  PWM_TDCR_IC3RDE                   ((u32)0x00000200)       /*!< input capture 3 rising edge DMA request enable */
#define  PWM_TDCR_IC3FDE                   ((u32)0x00000400)       /*!< input capture 3 falling edge DMA request enable */
#define  PWM_TDCR_IC4RDE                   ((u32)0x00000800)       /*!< input capture 4 rising edge DMA request enable */
#define  PWM_TDCR_IC4FDE                   ((u32)0x00001000)       /*!< input capture 4 falling edge DMA request enable */
#define  PWM_TDCR_TDE                      ((u32)0x00004000)       /*!< trigger DMA request enable            */
#define  PWM_TDCR_UDE                      ((u32)0x00008000)       /*!< update DMA request enable            */

/*******************  Bit definition for PWM_TACR register  *******************/  
#define  PWM_TACR_OC1UE                    ((u32)0x00000001)       /*!< CMU_OC1 trigger ADC enable */
#define  PWM_TACR_OC1DE                    ((u32)0x00000002)       /*!< CMD_OC1 trigger ADC enable */
#define  PWM_TACR_OC2UE                    ((u32)0x00000004)       /*!< CMU_OC2 trigger ADC enable */
#define  PWM_TACR_OC2DE                    ((u32)0x00000008)       /*!< CMD_OC2 trigger ADC enable */
#define  PWM_TACR_OC3UE                    ((u32)0x00000010)       /*!< CMU_OC3 trigger ADC enable */
#define  PWM_TACR_OC3DE                    ((u32)0x00000020)       /*!< CMD_OC3 trigger ADC enable */
#define  PWM_TACR_OC4UE                    ((u32)0x00000040)       /*!< CMU_OC4 trigger ADC enable */
#define  PWM_TACR_OC4DE                    ((u32)0x00000080)       /*!< CMD_OC4 trigger ADC enable */
#define  PWM_TACR_UOAE                     ((u32)0x00000100)       /*!< UpOVF trigger ADC enable   */
#define  PWM_TACR_DOAE                     ((u32)0x00000200)       /*!< DownOVF trigger ADC enable */
#define  PWM_TACR_TAE                      ((u32)0x00000400)       /*!< TEV trigger ADC enable     */
#define  PWM_TACR_IC1RAE                   ((u32)0x00010000)       /*!< IC1R trigger ADC enable    */
#define  PWM_TACR_IC1FAE                   ((u32)0x00020000)       /*!< IC1F trigger ADC enable    */
#define  PWM_TACR_IC2RAE                   ((u32)0x00040000)       /*!< IC2R trigger ADC enable    */
#define  PWM_TACR_IC2FAE                   ((u32)0x00080000)       /*!< IC2F trigger ADC enable    */
#define  PWM_TACR_IC3RAE                   ((u32)0x00100000)       /*!< IC3R trigger ADC enable    */
#define  PWM_TACR_IC3FAE                   ((u32)0x00200000)       /*!< IC3F trigger ADC enable    */
#define  PWM_TACR_IC4RAE                   ((u32)0x00400000)       /*!< IC4R trigger ADC enable    */
#define  PWM_TACR_IC4FAE                   ((u32)0x00800000)       /*!< IC4F trigger ADC enable    */

/******************************************************************************/
/*                                                                            */
/*                      CRC Registers                                     */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for CRC_CR register  *******************/  
#define CRC_CR_EN                          ((u32)0x00000001)          /*!< CRC Enable */
#define CRC_CR_CRS                         ((u32)0x00000002)          /*!< CRC reset control */
#define CRC_CR_CIS                         ((u32)0x00000004)          /*!< CRC input select */
#define CRC_CR_CISN                        ((u32)0x00000008)          /*!< CRC input bit sequence reversal */
#define CRC_CR_CBN                         ((u32)0x00000010)          /*!< CRC input byte sequence reversal */
#define CRC_CR_COSN                        ((u32)0x00000020)          /*!< CRC output bit sequence reversal */

/******************************************************************************/
/*                                                                            */
/*                        Independent WATCHDOG (WDG)                          */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for WDG_RLR register  *******************/
#define  WDG_RLR_RL                         ((u32)0xFFFFFFFF)            /*!< Watchdog counter reload value */

/*******************  Bit definition for WDG_Count register  *******************/ 
#define  WDG_CNT_CNT                        ((u32)0xFFFFFFFF)            /*!< Watchdog count value          */

/*******************  Bit definition for WDG_CR register  *******************/  
#define  WDG_CR_EN                          ((u32)0x00000001)       		/*!< Enable WDG        */
#define  WDG_CR_RSTE                        ((u32)0x00000002)       		/*!< RESET WDG         */
#define  WDG_CR_DBGE                        ((u32)0x00000004)       		/*!< DEBUG WDG         */

/*******************  Bit definition for WDG_KR register  *******************/ 
#define  WDG_KR_KEY                         ((u32)0xFFFFFFFF)       		/*!< key value         */

/*******************  Bit definition for WDG_SR register  *******************/  
#define  WDG_SR_HDF                         ((u32)0x00000001)           /*!< hungry dog flag */

/*******************  Bit definition for WDG_KR register  ********************/
#define  WDG_LOCK_KEY                       ((u32)0xFFFFFFFF)            /*!< lock key */
#define  WDG_LOCK_LOCK                      ((u32)0x00000001)            /*!< lock status */

/******************************************************************************/
/*                                                                            */
/*                        Independent BEEP (BEEP)                         		*/
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for BEEP_CR register  ********************/
#define  BEEP_CR_EN                         ((u32)0x00000001)       /*!< BEEP enable */
#define  BEEP_CR_PSC                        ((u32)0x0000001E)       /*!< Prescaler value */
#define  BEEP_CR_DIV                        ((u32)0x000000C0)       /*!< BEEP Clock divider */

/*******************  Bit definition for BEEP_HCR register ********************/
#define  BEEP_HCR_BEEP1E                    ((u32)0x00000001)				/*!< BEEP1 High sink enable */

/******************************************************************************/
/*                                                                            */
/*                        DMA  Registers                                      */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for DMA_CCR register  ********************/
#define  DMA_CCR_EN                         ((u32)0x00000001)           /*!< DMA channel enable                             */
#define  DMA_CCR_SINC                       ((u32)0x00000002)           /*!< Source address increment control               */
#define  DMA_CCR_DINC                       ((u32)0x00000004)           /*!< Destination address increment control             */
#define  DMA_CCR_SSIZE                      ((u32)0x00000018)           /*!< Source data size  */
#define  DMA_CCR_BURST                      ((u32)0x00000060)           /*!< Burst transfer configuration */
#define  DMA_CCR_DSIZE                      ((u32)0x00000180)           /*!< Destination data size   */
#define  DMA_CCR_DIR                        ((u32)0x00003800)           /*!< Direction                     */
#define  DMA_CCR_CIRC                       ((u32)0x00004000)           /*!< Circular mode                 */

/*******************  Bit definition for DMA_IER register  ********************/
#define  DMA_IER_TC0E                       ((u32)0x00000001)           /*!< DMA channel 0 transfer complete interrupt enable               */
#define  DMA_IER_TC1E                       ((u32)0x00000002)           /*!< DMA channel 1 transfer complete interrupt enable               */
#define  DMA_IER_TE0E                       ((u32)0x00000010)           /*!< DMA channel 0 transfer error interrupt enable               */
#define  DMA_IER_TE1E                       ((u32)0x00000020)           /*!< DMA channel 1 transfer error interrupt enable               */
#define  DMA_IER_CEE                        ((u32)0x80000000)           /*!< DMA channel configuration error interrupt enable                        */

/*******************  Bit definition for DMA_SR register  ********************/
#define  DMA_SR_TC0F                        ((u32)0x00000001)           /*!< DMA channel 0 transfer complete interrupt flag               */
#define  DMA_SR_TC1F                        ((u32)0x00000002)           /*!< DMA channel 1 transfer complete interrupt flag               */
#define  DMA_SR_TE0F                        ((u32)0x00000010)           /*!< DMA channel 0 transfer error interrupt flag               */
#define  DMA_SR_TE1F                        ((u32)0x00000020)           /*!< DMA channel 1 transfer error interrupt flag               */
#define  DMA_SR_BSY0                        ((u32)0x00000100)           /*!< DMA channel 0 busy flag         			    */
#define  DMA_SR_BSY1                        ((u32)0x00000200)           /*!< DMA channel 1 busy flag             			*/
#define  DMA_SR_CEF                         ((u32)0x80000000)           /*!< DMA channel configuration error interrupt flag                        */

/*******************  Bit definition for DMA_CHAPCR register  ********************/
#define  DMA_CHAPCR_CHSEL                   ((u32)0x0000001F)           /*!< DMA channel x peripheral selection                             */


/******************************************************************************/
/*                                                                            */
/*                        ALU  Registers                                      */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for ALU_CR register  ********************/
#define  ALU_CR_MODE                        ((u32)0x00000007)           /*!< Operation mode selection                             */
#define  ALU_CR_START                       ((u32)0x00000008)           /*!< Start calculation                                 */
#define  ALU_CR_QFMT                        ((u32)0x000001F0)           /*!< Q format data type                            */
#define  ALU_CR_MACL                        ((u32)0x00001000)           /*!< Multiply and accumulate operation limit enable                         */
#define  ALU_CR_SIGN                        ((u32)0x00002000)           /*!< Operand sign bit enable                         */

/*******************  Bit definition for ALU_IE register  ********************/
#define  ALU_IE_DIE                         ((u32)0x00000001)           /*!< Operation done interrupt enable                         */
#define  ALU_IE_ERRIE                       ((u32)0x00000002)           /*!< Operation error interrupt enable                         */
#define  ALU_IE_OVFIE                       ((u32)0x00000004)           /*!< Operation overflow interrupt enable                         */

/*******************  Bit definition for ALU_SR register  ********************/
#define  ALU_SR_DONE                        ((u32)0x00000001)           /*!< Operation done flag                             */
#define  ALU_SR_ERR                         ((u32)0x00000002)           /*!< Operation error flag                             */
#define  ALU_SR_OVF                         ((u32)0x00000004)           /*!< Operation overflow flag                             */
#define  ALU_SR_BSY                         ((u32)0x00000008)           /*!< Operation busy flag                           */

/*******************  Bit definition for ALU_OPDXR register  ********************/
#define  ALU_OPDXR_OPDX                     ((u32)0xFFFFFFFF)           /*!< Operand X                         */

/*******************  Bit definition for ALU_OPDYR register  ********************/
#define  ALU_OPDYR_OPDY                     ((u32)0xFFFFFFFF)           /*!< Operand Y                         */

/*******************  Bit definition for ALU_OPDZR register  ********************/
#define  ALU_OPDZR_OPDZ                     ((u32)0xFFFFFFFF)           /*!< Operand Z                         */

/*******************  Bit definition for ALU_OPDWR register  ********************/
#define  ALU_OPDWR_OPDW                     ((u32)0xFFFFFFFF)           /*!< Operand W                         */

/*******************  Bit definition for ALU_DHR register  ********************/
#define  ALU_DHR_DATAH                      ((u32)0xFFFFFFFF)           /*!< Data high 32-bit                           */

/*******************  Bit definition for ALU_DLR register  ********************/
#define  ALU_DLR_DATAL                      ((u32)0xFFFFFFFF)           /*!< Data low 32-bit                           */

/*******************  Bit definition for ALU_MAMAXHR register  ********************/
#define  ALU_MAMAXHR_MAXH                   ((u32)0xFFFFFFFF)           /*!< MAC maximum threshold high 32-bit                 */

/*******************  Bit definition for ALU_MAMAXLR register  ********************/
#define  ALU_MAMAXLR_MAXL                   ((u32)0xFFFFFFFF)           /*!< MAC maximum threshold low 32-bit                 */

/*******************  Bit definition for ALU_MAMINHR register  ********************/
#define  ALU_MAMINHR_MINH                   ((u32)0xFFFFFFFF)           /*!< MAC minimum threshold high 32-bit                 */

/*******************  Bit definition for ALU_MAMINLR register  ********************/
#define  ALU_MAMINLR_MINL                   ((u32)0xFFFFFFFF)           /*!< MAC minimum threshold low 32-bit                 */

/*******************  Bit definition for ALU_DRR register  ********************/
#define  ALU_DRR_ROD                        ((u32)0xFFFFFFFF)           /*!< Remainder of division                           */


#ifdef USE_STDPERIPH_DRIVER
  #include "PT32x030x_conf.h"
#endif

  
#ifdef __cplusplus
}
#endif

#endif 

