/********************************************************************************
  * @file    pt32x030x_adc.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the ADC firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
  
#ifndef PT32x030x_ADC_H
#define PT32x030x_ADC_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "PT32x030x.h"

/** @defgroup ADC_InitTypeDef
* @{ 
*/
typedef struct
{
    u32 ADC_Prescaler;									/*!< Specifies the ADC prescaler,
																						 This parameter can be a value of @ref ADC_Prescaler */
	
    u32 ADC_Mode;												/*!< Specifies the ADC mode,
																						 This parameter can be a value of @ref ADC_Mode */
	
    u32 ADC_TriggerSource;							/*!< Specifies the ADC trigger source selection,
																						 This parameter can be a value of @ref ADC_TriggerSource */
	
    u32 ADC_TimerTriggerSource;					/*!< Specifies the ADC timing trigger source selection,
																						 This parameter can be a value of @ref ADC_TimerTriggerSource */
	
    u32 ADC_ExternalPinTriggerSource;		/*!< Specifies the ADC timing trigger source selection,
																						 This parameter can be a value of @ref ADC_ExternalPinTriggerSource */
	
    u32 ADC_Align;											/*!< Specifies the ADC ALIGN,
																						 This parameter can be a value of @ref ADC_Align */
	
    u32 ADC_Channel;										/*!< Specifies the ADC channel selection,
																						 This parameter can be a value of @ref ADC_Channel */
	
	  u32 ADC_BGVoltage;									/*!< Specifies the ADC bg voltage selection,
																						 This parameter can be a value of @ref ADC_BGVoltage	*/
																						 
    u32 ADC_VoltageReferencePositive;		/*!< Specifies the ADC voltage reference positive selection,
																						 This parameter can be a value of @ref ADC_VoltageReferencePositive */
																						 
}ADC_InitTypeDef;


/** @defgroup ADC_ALL_PERIPH
* @{ 
*/
#define IS_ADC_ALL_PERIPH(SEL)       ((SEL) == ADC)

/** @defgroup ADC_Prescaler
* @{ 
*/
#define IS_ADC_Prescaler(SEL)       ((SEL)<=127&&(SEL)>=1)

/** @defgroup ADC_Mode
* @{ 
*/
#define ADC_Mode_Single			                  (ADC_CR1_MODE&0x00000000)
#define ADC_Mode_Continuous	                      (ADC_CR1_MODE&0x00000002)
#define IS_ADC_Mode(SEL)        (((SEL) == ADC_Mode_Single)||\
								((SEL) == ADC_Mode_Continuous))
  

/** @defgroup ADC_TriggerSource
* @{ 
*/                                     
#define ADC_TriggerSource_Software                       (ADC_CR1_TRIGS&0x00000000)                              
#define ADC_TriggerSource_Timer                          (ADC_CR1_TRIGS&0x00000004)                                   
#define ADC_TriggerSource_ExternalPin                    (ADC_CR1_TRIGS&0x00000008)                           
#define IS_ADC_TriggerSource(SEL)       (((SEL) == ADC_TriggerSource_Software)||\
                                        ((SEL) == ADC_TriggerSource_Timer)||\
                                        ((SEL) == ADC_TriggerSource_ExternalPin))
                                        
/** @defgroup ADC_TimerTriggerSource
* @{ 
*/   
#define ADC_TimerTriggerSource_TIM1ADC                         (ADC_CR1_TIMS&0x00000010)         
#define ADC_TimerTriggerSource_TIM2ADC                         (ADC_CR1_TIMS&0x00000020)         
#define ADC_TimerTriggerSource_TIM3ADC                         (ADC_CR1_TIMS&0x00000030)         
#define ADC_TimerTriggerSource_TIM5ADC                         (ADC_CR1_TIMS&0x00000050)        
#define ADC_TimerTriggerSource_TIM6ADC                         (ADC_CR1_TIMS&0x00000060)        
#define ADC_TimerTriggerSource_TIM7ADC                         (ADC_CR1_TIMS&0x00000070)         
#define IS_ADC_TimerTriggerSource(SEL)       (((SEL) == ADC_TimerTriggerSource_TIM1ADC)||\
                                                ((SEL) == ADC_TimerTriggerSource_TIM2ADC)||\
                                                ((SEL) == ADC_TimerTriggerSource_TIM3ADC)||\
                                                ((SEL) == ADC_TimerTriggerSource_TIM5ADC)||\
                                                ((SEL) == ADC_TimerTriggerSource_TIM6ADC)||\
                                                ((SEL) == ADC_TimerTriggerSource_TIM7ADC))

/** @defgroup ADC_ExternalPinTriggerSource
* @{ 
*/
#define ADC_ExternalPinTriggerSource_ADCETR        (ADC_CR1_EXTS&0x00000000)
#define ADC_ExternalPinTriggerSource_TIM1CH4       (ADC_CR1_EXTS&0x20000000)

#define IS_ADC_ExternalPinTriggerSource(SEL)       (((SEL)==ADC_ExternalPinTriggerSource_ADCETR)||\
                                                ((SEL)==ADC_ExternalPinTriggerSource_TIM1CH4))
                                                
/** @defgroup ADC_Align
* @{ 
*/
#define ADC_Align_Right     (ADC_CR1_ALIGN&0x00000000)
#define ADC_Align_Left      (ADC_CR1_ALIGN&0x00000800)
#define IS_ADC_Align(SEL)       (((SEL) == ADC_Align_Right) || \
                                ((SEL) == ADC_Align_Left))
/** @defgroup ADC_Channel
* @{ 
*/
#define ADC_Channel_0                             (ADC_CR1_CHS&0x00000000)                            
#define ADC_Channel_1                             (ADC_CR1_CHS&0x00010000)                                    
#define ADC_Channel_2                             (ADC_CR1_CHS&0x00020000)                                   
#define ADC_Channel_3                             (ADC_CR1_CHS&0x00030000)                                       
#define ADC_Channel_4                             (ADC_CR1_CHS&0x00040000)                                         
#define ADC_Channel_5                             (ADC_CR1_CHS&0x00050000)                                    
#define ADC_Channel_6                             (ADC_CR1_CHS&0x00060000)                                       
#define ADC_Channel_7                             (ADC_CR1_CHS&0x00070000)                                  
#define ADC_Channel_8                             (ADC_CR1_CHS&0x00080000)                                    
#define ADC_Channel_9                             (ADC_CR1_CHS&0x00090000)                                    
#define ADC_Channel_10                            (ADC_CR1_CHS&0x000A0000)                                   
#define ADC_Channel_11                            (ADC_CR1_CHS&0x000B0000)                                   
#define ADC_Channel_12                            (ADC_CR1_CHS&0x000C0000)                                     
#define ADC_Channel_13                            (ADC_CR1_CHS&0x00110000)                                  
#define ADC_Channel_14                            (ADC_CR1_CHS&0x00120000)                                  
#define ADC_Channel_15                            (ADC_CR1_CHS&0x00130000)         
#define ADC_Channel_16                            (ADC_CR1_CHS&0x000D0000)                        
#define ADC_Channel_17                            (ADC_CR1_CHS&0x000E0000)         
#define ADC_Channel_18                            (ADC_CR1_CHS&0x00100000)         
#define IS_ADC_Channel(SEL)     (((SEL) == ADC_Channel_0)||\
                                ((SEL) == ADC_Channel_1)||\
                                ((SEL) == ADC_Channel_2)||\
                                ((SEL) == ADC_Channel_3)||\
                                ((SEL) == ADC_Channel_4)||\
                                ((SEL) == ADC_Channel_5)||\
                                ((SEL) == ADC_Channel_6)||\
                                ((SEL) == ADC_Channel_7)||\
                                ((SEL) == ADC_Channel_8)||\
                                ((SEL) == ADC_Channel_9)||\
                                ((SEL) == ADC_Channel_10)||\
                                ((SEL) == ADC_Channel_11)||\
                                ((SEL) == ADC_Channel_12)||\
                                ((SEL) == ADC_Channel_13)||\
                                ((SEL) == ADC_Channel_14)||\
                                ((SEL) == ADC_Channel_15)||\
                                ((SEL) == ADC_Channel_16)||\
                                ((SEL) == ADC_Channel_17)||\
                                ((SEL) == ADC_Channel_18))

                                        
/** @defgroup ADC_BGVoltage
* @{ 
*/
#define ADC_BGVoltage_BG1v2     (ADC_CR1_BGS&0x00000000)
#define ADC_BGVoltage_BG1v0     (ADC_CR1_BGS&0x00200000)
 
#define IS_ADC_BGVoltage(SEL)       (((SEL)==ADC_BGVoltage_BG1v2)||\
                                    ((SEL)==ADC_BGVoltage_BG1v0))

/** @defgroup ADC_VoltageReferencePositive
* @{ 
*/
#define ADC_VoltageReferencePositive_VDDA     (ADC_CR1_ADVRPS&0x00000000)
#define ADC_VoltageReferencePositive_VREF     (ADC_CR1_ADVRPS&0x04000000)
 
#define IS_ADC_VoltageReferencePositive(SEL)       (((SEL)==ADC_VoltageReferencePositive_VDDA)||\
                                    ((SEL)==ADC_VoltageReferencePositive_VREF))
                                    
/** @defgroup ADC_IT
* @{ 
*/
#define ADC_IT_EOC      ADC_CR1_EOCIE
#define ADC_IT_EOS      ADC_CR1_EOSIE
                    
#define IS_ADC_IT(SEL)      (((SEL)==ADC_IT_EOC)||\
                            ((SEL)==ADC_IT_EOS))
                            
/** @defgroup ADC_FLAG
* @{ 
*/
#define ADC_FLAG_RDY        ADC_SR_RDY
#define ADC_FLAG_EOC        ADC_SR_EOC
#define ADC_FLAG_EOS        ADC_SR_EOS

#define IS_ADC_FLAG(SEL)        (((SEL) == ADC_FLAG_RDY)||\
                                ((SEL) == ADC_FLAG_EOC)||\
                                ((SEL) == ADC_FLAG_EOS))     
 
/** @defgroup ADC_AverageTimes
* @{ 
*/
#define ADC_AverageTimes_1     (ADC_CR2_AVGT&0x00000000)         
#define ADC_AverageTimes_2     (ADC_CR2_AVGT&0x01000000)         
#define ADC_AverageTimes_4     (ADC_CR2_AVGT&0x02000000)         
#define ADC_AverageTimes_8     (ADC_CR2_AVGT&0x03000000)        
#define ADC_AverageTimes_16    (ADC_CR2_AVGT&0x04000000)        
#define ADC_AverageTimes_32    (ADC_CR2_AVGT&0x05000000)         
#define ADC_AverageTimes_64    (ADC_CR2_AVGT&0x06000000)         
#define ADC_AverageTimes_128   (ADC_CR2_AVGT&0x07000000)         

#define IS_ADC_AverageTimes(SEL)       (((SEL)==ADC_AverageTimes_1)||\
                                                    ((SEL)==ADC_AverageTimes_2)||\
                                                    ((SEL)==ADC_AverageTimes_4)||\
                                                    ((SEL)==ADC_AverageTimes_8)||\
                                                    ((SEL)==ADC_AverageTimes_16)||\
                                                    ((SEL)==ADC_AverageTimes_32)||\
                                                    ((SEL)==ADC_AverageTimes_64)||\
                                                    ((SEL)==ADC_AverageTimes_128))

/** @defgroup ADC_ReadyTime
* @{ 
*/
#define IS_ADC_ReadyTime(SEL)    ((SEL)<=0xFF)

/** @defgroup ADC_SampleTime
* @{ 
*/
#define IS_ADC_SampleTime(SEL)      ((SEL)<=0x7F)


/** @defgroup ADC_TrimValue
* @{ 
*/																																																			
#define IS_ADC_TrimValue(SEL)     ((SEL)<=0x3F)		

 /** @defgroup ADC_ScanChannel
* @{ 
*/
#define IS_ADC_ScanChannel(SEL)     ((SEL)<=19)	
 
/** @defgroup ADC_ScanChannelNumber
* @{ 
*/
#define IS_ADC_ScanChannelNumber(SEL)       (((SEL)>=2)&&((SEL)<=20))	


/*! function declaration and definition*/
void ADC_Init(ADC_TypeDef* ADCx, ADC_InitTypeDef* ADC_InitStruct);
void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_ChannelConfig(ADC_TypeDef* ADCx, u32 ADC_Channel);
void ADC_StartOfConversion(ADC_TypeDef* ADCx);
u16 ADC_GetConversionValue(ADC_TypeDef* ADCx);

void ADC_ITConfig(ADC_TypeDef* ADCx, u32 ADC_IT, FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef* ADCx, u32 ADC_FLAG);

void ADC_AverageCmd(ADC_TypeDef* ADCx,FunctionalState NewState);
void ADC_AverageTimesConfig(ADC_TypeDef* ADCx,u32 Times);
void ADC_ReadyTimeConfig(ADC_TypeDef* ADCx,u32 ReadyTime);
void ADC_SampleTimeConfig(ADC_TypeDef* ADCx,u32 SampleTime);

void ADC_TrimCmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_TrimValueConfig(ADC_TypeDef* ADCx,s32 Value);

void ADC_ScanCmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_ScanChannelConfig(ADC_TypeDef* ADCx,u32 ADC_Channel,u32 ScanChannel);
void ADC_ScanChannelNumberConfig(ADC_TypeDef* ADCx,u32 ScanNumber);

void ADC_DMACmd(ADC_TypeDef* ADCx, FunctionalState NewState);
#ifdef __cplusplus
}
#endif

#endif /*__PT32x030x_ADC_H */
