/**
  ******************************************************************************
  * @file    PT32X03X_beep.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief   This file contains all the functions prototypes for the BEEP firmware library
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x030x_BEEP_H
#define PT32x030x_BEEP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x030x.h"

/** @addtogroup BEEP
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  BEEP Init structure definition
  */

typedef struct
{
	u32 BEEP_PrescalerValue;    /*!< Specifies the beep prescaler value.
								                   This parameter can be a number between 0x00 and 0x1F */		
	
	u32 BEEP_ClockDivider;      /*!< Specifies the beep clock divider value.
								                   This parameter can be a value of @ref BEEP_clock_division_selection */			
	
}Beep_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IS_BEEP_ALL_PERIPH 
  * @{
  */
#define IS_BEEP_ALL_PERIPH(SEL)    	((SEL) == BEEP)
/**
  * @}
  */

/** @defgroup BEEP_clock_division_selection 
  * @{
  */
#define BEEP_ClockDivider_2       ((u32)0x00000080)
#define BEEP_ClockDivider_4       ((u32)0x00000040)
#define BEEP_ClockDivider_8       ((u32)0x00000000)
#define IS_BEEP_ClockDivider(SEL) (((SEL) == BEEP_ClockDivider_2)   || \
                                   ((SEL) == BEEP_ClockDivider_4)   || \
                                   ((SEL) == BEEP_ClockDivider_8))
/**
  * @}
  */

/** @defgroup IS_BEEP_PSC 
  * @{
  */
#define IS_BEEP_Prescaler(SEL) 		 ((SEL) <= 0x1F)
/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void Beep_Init(Beep_InitTypeDef* Beep_InitStruct);
void Beep_Cmd(FunctionalState NewState);
void Beep_DeInit(void);
void Beep_HighSinkConfig(BEEP_TypeDef* BEEPx, FunctionalState NewState);

/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif 
