/******************************************************************************
  * @file    PT32x030x_cmp.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief    This file contains all the functions prototypes for the CMP firmware library
  *
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x030x_CMP_H
#define PT32x030x_CMP_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x030x.h"

/** @addtogroup CMP
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  CMP Init structure definition
  */

typedef struct
{
	u32 CMP_NegativeInput;					/*!< Specifies the negative intput selection.
																			 This parameter can be a value of @ref CMP_negative_input_selection */
	
	u32 CMP_DigitalFilter;					/*!< Specifies the digital filter configuration.
																			 This parameter can be a value of @ref CMP_digital_filter_configuration */
	
	u32 CMP_PowerMode;							/*!< Specifies the power mode selection.
																			 This parameter can be a value of @ref CMP_power_mode_selection */
	
	u32 CMP_OutputPolarity;					/*!< Specifies the output polarity control.
																			 This parameter can be a value of @ref CMP_output_polarity_selection */
	
	u32 CMP_Hysteresis;							/*!< Specifies the hysteresis control.
																			 This parameter can be a value of @ref CMP_hysteresis_selection 
																			 @note this bit is only valid for CMP1 */
	
	u32 CMP_PositiveInput;					/*!< Specifies the positive intput selection.
																			 This parameter can be a value of @ref CMP_positive_input_selection 
																			 @note this bit is only valid for CMP0 or CMP2 */
																	 
	u32 CMP_InitializationDelayTime;/*!< Specifies the initialization delay time.
																	     This parameter can be a number between  0x000 and 0x3FF */
																	 
} CMP_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup CMP_periph_selection
  * @{
  */
#define IS_CMP_ALL_PERIPH(SEL)	 		(((SEL) == CMP0) || ((SEL) == CMP1) || ((SEL) == CMP2))
/**
  * @}
  */

/** @defgroup CMP_negative_input_selection
  * @{
  */
#define CMP_NegativeInput_CMPxN		(CMP_CR1_CPS&0x00)   
#define CMP_NegativeInput_LDAC		(CMP_CR1_CPS&0x04)   
#define CMP_NegativeInput_BG1V0		(CMP_CR1_CPS&0x08)   
#define IS_CMP_NegativeInput(SEL)	 (((SEL) == CMP_NegativeInput_CMPxN) ||\
																		((SEL) == CMP_NegativeInput_LDAC)  ||\
																		((SEL) == CMP_NegativeInput_BG1V0))
/**
  * @}
  */

/** @defgroup CMP_digital_filter_configuration 
  * @{
  */
#define CMP_DigitalFilter_None	(CMP_CR1_DFC&0x00)    
#define CMP_DigitalFilter_2			(CMP_CR1_DFC&0x10)    
#define CMP_DigitalFilter_4			(CMP_CR1_DFC&0x20)   
#define CMP_DigitalFilter_8			(CMP_CR1_DFC&0x30) 	 
#define CMP_DigitalFilter_16		(CMP_CR1_DFC&0x40)    
#define CMP_DigitalFilter_32		(CMP_CR1_DFC&0x50)    
#define CMP_DigitalFilter_64		(CMP_CR1_DFC&0x60)    
#define IS_CMP_DigitalFilter(SEL)		(((SEL) == CMP_DigitalFilter_None) ||\
																		 ((SEL) == CMP_DigitalFilter_2) 	 ||\
																		 ((SEL) == CMP_DigitalFilter_4) 	 ||\
																		 ((SEL) == CMP_DigitalFilter_8) 	 ||\
																		 ((SEL) == CMP_DigitalFilter_16)  ||\
																		 ((SEL) == CMP_DigitalFilter_32)  ||\
																		 ((SEL) == CMP_DigitalFilter_64))
/**
  * @}
  */

/** @defgroup CMP_power_mode_selection 
  * @{
  */
#define CMP_PowerMode_LowPower	 (CMP_CR1_CPMS&0x00)
#define CMP_PowerMode_HighSpeed  (CMP_CR1_CPMS&0x80)
#define IS_CMP_PowerMode(SEL) 	 ((SEL==CMP_PowerMode_HighSpeed)||(SEL==CMP_PowerMode_LowPower))
/**
  * @}
  */

/** @defgroup CMP_output_polarity_selection 
  * @{
  */
#define CMP_OutputPolarity_Normal 			 (CMP_CR1_OPC&0x000)
#define CMP_OutputPolarity_Inverted			 (CMP_CR1_OPC&0x100)
#define IS_CMP_OutputPolarity(SEL)       ((SEL==CMP_OutputPolarity_Normal)||\
																				  (SEL==CMP_OutputPolarity_Inverted))
/**
  * @}
  */

/** @defgroup CMP_hysteresis_selection 
  * @{
  */
#define CMP_Hysteresis_Disable		 (CMP_CR1_HYS&0x000)
#define CMP_Hysteresis_Enable 		 (CMP_CR1_HYS&0x100)
#define IS_CMP_Hysteresis(SEL)  	 ((SEL==CMP_Hysteresis_Disable)||(SEL==CMP_Hysteresis_Enable))
/**
  * @}
  */

/** @defgroup CMP_positive_input_selection 
  * @{
  */
#define CMP_PositiveInput_CMPxP0	(CMP_CR1_CPS&0x0000)
#define CMP_PositiveInput_CMPxP1 	(CMP_CR1_CPS&0x1000)
#define CMP_PositiveInput_CMPxP2	(CMP_CR1_CPS&0x2000)
#define CMP_PositiveInput_CMPxP3  (CMP_CR1_CPS&0x3000)
#define IS_CMP_PositiveInput(SEL) ((SEL==CMP_PositiveInput_CMPxP0)	||\
																	 (SEL==CMP_PositiveInput_CMPxP1)	||\
																	 (SEL==CMP_PositiveInput_CMPxP2)	||\
																	 (SEL==CMP_PositiveInput_CMPxP3))
/**
  * @}
  */

/** @defgroup CMP_interrupt_selection 
  * @{
  */
#define CMP_IT_COF					CMP_IE_COF
#define CMP_IT_COR					CMP_IE_COR
#define CMP_IT_COFW					CMP_IE_COFW
#define CMP_IT_CORW					CMP_IE_CORW
#define IS_CMP_IT(SEL)    	 (((SEL) == CMP_IT_COF) 		 ||\
															((SEL) == CMP_IT_COR) 		 ||\
															((SEL) == CMP_IT_COFW) 		 ||\
															((SEL) == CMP_IT_CORW))
/**
  * @}
  */

/** @defgroup CMP_state_flag_selection 
  * @{
  */
#define CMP_FLAG_COF				CMP_SR_COF
#define CMP_FLAG_COR				CMP_SR_COR
#define CMP_FLAG_COFW				CMP_SR_COFW
#define CMP_FLAG_CORW				CMP_SR_CORW
#define IS_CMP_FLAG(SEL) 			(((SEL) == CMP_FLAG_COF) 		 ||\
                               ((SEL) == CMP_FLAG_COR) 		 ||\
                               ((SEL) == CMP_FLAG_COFW) 	 ||\
                               ((SEL) == CMP_FLAG_CORW))
/**
  * @}
  */

/** @defgroup IS_CMP_InitDelay 
  * @{
  */
#define IS_CMP_InitializationDelayTime(SEL) 			((SEL) <= 0x3FF )
/**
  * @}
  */
											 
/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void CMP_DeInit(CMP_TypeDef* CMPx);
void CMP_Init(CMP_TypeDef* CMPx, CMP_InitTypeDef* CMP_InitStruct);
void CMP_StructInit(CMP_InitTypeDef* CMP_InitStruct);
void CMP_Cmd(CMP_TypeDef* CMPx, FunctionalState NewState);
void CMP_ITConfig(CMP_TypeDef* CMPx, u32 CMP_IT, FunctionalState NewState);
FlagStatus CMP_GetFlagStatus(CMP_TypeDef* CMPx, u32 CMP_FLAG);
void CMP_ClearFlag(CMP_TypeDef* CMPx, u32 CMP_FLAG);
ITStatus CMP_GetITStatus(CMP_TypeDef* CMPx, u32 CMP_IT);


/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif

