/********************************************************************************
  * @file    PT32x030x_crc.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the CRC firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32X030_CRC_H
#define PT32X030_CRC_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x030x.h"


/** @defgroup CRC_InitTypeDef
* @{ 
*/
typedef struct
{
	u32 CRC_Input;											/*!< Specifies the CRC input,
																					 This parameter can be a value of @ref CRC_Input */
	
	u32 CRC_InputBitSequenceReversal;		/*!< Specifies the CRC input Bit Sequence Reversal,
																					 This parameter can be a value of @ref CRC_InputBitSequenceReversal */
	
	u32 CRC_InputByteSequenceReversal;	/*!< Specifies the CRC input Byte Sequence Reversal,
																					 This parameter can be a value of @ref CRC_InputByteSequenceReversal */
	
	u32 CRC_OutputBitSequenceReversal;	/*!< Specifies the CRC Output Bit Sequence Reversal,
																				   This parameter can be a value of @ref CRC_OutputBitSequenceReversal */
	
	u32 CRC_Seed;												/*!< Specifies the CRC Seed,
																					 This parameter can be a value of @ref CRC_Seed */
	
	u32 CRC_Poly;												/*!< Specifies the CRC Poly,
																					 This parameter can be a value of @ref CRC_Poly */
	
} CRC_InitTypeDef;

/** @defgroup CRC_Input
* @{ 
*/
#define CRC_Input_8b		                     (CRC_CR_CIS&0x00000000)	       //!< CRC DataIn Width 8bit
#define CRC_Input_16b		                     (CRC_CR_CIS&0x00000004)	       //!< CRC DataIn Width 16bit
#define IS_CRC_Input(SEL)		((SEL == CRC_Input_8b) || \
														(SEL == CRC_Input_16b))

/** @defgroup CRC_InputBitSequenceReversal
* @{ 
*/
#define CRC_InputBitSequenceReversal_Disable		    	(CRC_CR_CISN&0x00000000)	       
#define CRC_InputBitSequenceReversal_Enable		        (CRC_CR_CISN&0x00000008)	       
#define IS_CRC_InputBitSequenceReversal(SEL)		((SEL == CRC_InputBitSequenceReversal_Disable) || \
																								(SEL == CRC_InputBitSequenceReversal_Enable))

/** @defgroup CRC_InputByteSequenceReversal
* @{ 
*/
#define CRC_InputByteSequenceReversal_Disable		    		(CRC_CR_CBN&0x00000000)	       
#define CRC_InputByteSequenceReversal_Enable		        (CRC_CR_CBN&0x00000010)	      
#define IS_CRC_InputByteSequenceReversal(SEL)		((SEL == CRC_InputByteSequenceReversal_Disable) || \
																								(SEL == CRC_InputByteSequenceReversal_Enable))

/** @defgroup CRC_OutputBitSequenceReversal
* @{ 
*/
#define CRC_OutputBitSequenceReversal_Disable		    		(CRC_CR_COSN&0x00000000)	      
#define CRC_OutputBitSequenceReversal_Enable		        (CRC_CR_COSN&0x00000020)	       
#define IS_CRC_OutputBitSequenceReversal(SEL)		((SEL == CRC_OutputBitSequenceReversal_Disable) || \
																								(SEL == CRC_OutputBitSequenceReversal_Enable))

/** @defgroup CRC_Seed
* @{ 
*/
#define IS_CRC_Seed(SEL)	((SEL) <= 0xFFFF)

/** @defgroup CRC_Poly
* @{ 
*/
#define IS_CRC_Poly(SEL)	((SEL) <= 0xFFFF)

#define CRC_CCITT16	    0x00001021           //!< 0x1021
#define CRC_IBM16				0x00008005           //!< 0x8005

/*! function declaration and definition*/
void CRC_Init(CRC_InitTypeDef* CRC_InitStruct);
void CRC_StructInit(CRC_InitTypeDef* CRC_InitStruct);
void CRC_Cmd(FunctionalState NewState);
void CRC_ResetDout(void);
u32 CRC_CalculateCRC(u16 CRC_Data);
u32 CRC_CalculateBlockCRC(u16 pBuffer[], u32 BufferLength);
u32 CRC_GetCRC(void);
  
#ifdef __cplusplus
}
#endif

#endif


