/********************************************************************************
  * @file    PT32x030x_dma.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the DMA firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x030x_DMA_H
#define PT32x030x_DMA_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "PT32x030x.h"

/** @defgroup DMA_InitTypeDef
* @{ 
*/
typedef struct
{
  u32 DMA_SourceBaseAddress;          	/*!< Specifies the Source Address,
																						 This parameter can be a value of @ref DMA_SourceBaseAddress */
	
  u32 DMA_DestinationBaseAddress;     	/*!< Specifies the Destination Address,
																						 This parameter can be a value of @ref DMA_DestinationBaseAddress */
  
	u32 DMA_NumberOfData;          				/*!< Specifies the Number of Blocks for a DMA transfer,
																						 This parameter can be a value of @ref DMA_NumberOfData */
	
	u32 DMA_SourceDataSize;        				/*!< Specifies the DMA Source Data Size,
																						 This parameter can be a value of @ref DMA_SourceDataSize */
	
	u32 DMA_DestinationDataSize;     			/*!< Specifies the DMA Destination Data Size,
																						 This parameter can be a value of @ref DMA_DestinationDataSize */  
  
	u32 DMA_SourceAddressIncrement;       /*!< Specifies the DMA Source Address Increment,
																						 This parameter can be a value of @ref DMA_SourceAddressIncrement */
	
	u32 DMA_DestinationAddressIncrement;  /*!< Specifies the DMA Destination Address Increment,
																						 This parameter can be a value of @ref DMA_DestinationAddressIncrement */
	
	u32 DMA_Direction;										/*!< Specifies the DMA Direction,
																						 This parameter can be a value of @ref DMA_Direction */
																						 
	u32 DMA_CircularMode;									/*!< Specifies the DMA Circular mode,
																						 This parameter can be a value of @ref DMA_CircularMode */
																						 
} DMA_InitTypeDef;


/** @defgroup DMA_ALL_PERIPH
* @{ 
*/
#define IS_DMA_ALL_PERIPH(SEL)      (((SEL) == DMA0) || \
                                    ((SEL) == DMA1))

/** @defgroup DMA_NumberOfData
* @{ 
*/
#define IS_DMA_NumberOfData(SEL)      ((SEL > 0) && (SEL < 65536))  //!<Number of data to transfer

/** @defgroup DMA_SourceDataSize
* @{ 
*/
#define DMA_SourceDataSize_Byte      (DMA_CCR_SSIZE&0x00000000)
#define DMA_SourceDataSize_Half      (DMA_CCR_SSIZE&0x00000008)
#define DMA_SourceDataSize_Word      (DMA_CCR_SSIZE&0x00000010)
#define IS_DMA_SourceDataSize(SEL)     (((SEL) == DMA_SourceDataSize_Byte) || \
                                        ((SEL) == DMA_SourceDataSize_Half) || \
                                        ((SEL) == DMA_SourceDataSize_Word))   //!<Source data size

/** @defgroup DMA_DestinationDataSize
* @{ 
*/
#define DMA_DestinationDataSize_Byte      (DMA_CCR_DSIZE&0x00000000)
#define DMA_DestinationDataSize_Half      (DMA_CCR_DSIZE&0x00000080)
#define DMA_DestinationDataSize_Word      (DMA_CCR_DSIZE&0x00000100)
#define IS_DMA_DestinationDataSize(SEL)    (((SEL) == DMA_DestinationDataSize_Byte) || \
                                            ((SEL) == DMA_DestinationDataSize_Half) || \
                                            ((SEL) == DMA_DestinationDataSize_Word))   //!<Destination data size

/** @defgroup DMA_SourceAddressIncrement
* @{ 
*/
#define DMA_SourceAddressIncrement_Disable    (DMA_CCR_SINC&0x00000000)      
#define DMA_SourceAddressIncrement_Enable     (DMA_CCR_SINC&0x00000002)   
#define IS_DMA_SourceAddressIncrement(SEL)       (((SEL) == DMA_SourceAddressIncrement_Disable) || \
                                                  ((SEL) == DMA_SourceAddressIncrement_Enable))      

/** @defgroup DMA_DestinationAddressIncrement
* @{ 
*/
#define DMA_DestinationAddressIncrement_Disable    (DMA_CCR_DINC&0x00000000)      
#define DMA_DestinationAddressIncrement_Enable     (DMA_CCR_DINC&0x00000004) 
#define IS_DMA_DestinationAddressIncrement(SEL)       (((SEL) == DMA_DestinationAddressIncrement_Disable) || \
																											 ((SEL) == DMA_DestinationAddressIncrement_Enable))      

/** @defgroup DMA_Direction
* @{ 
*/
#define DMA_Direction_PeripheralToMemory      (DMA_CCR_DIR&0x00000000)       
#define DMA_Direction_MemoryToMemory          (DMA_CCR_DIR&0x00000800)       
#define DMA_Direction_MemoryToPeripheral      (DMA_CCR_DIR&0x00002000)       
#define IS_DMA_Direction(SEL)       					 (((SEL) == DMA_Direction_PeripheralToMemory) || \
                                                ((SEL) == DMA_Direction_MemoryToMemory) || \
                                                ((SEL) == DMA_Direction_MemoryToPeripheral))    

/** @defgroup DMA_CircularMode
* @{ 
*/
#define DMA_CircularMode_Disable    (DMA_CCR_CIRC&0x00000000)      
#define DMA_CircularMode_Enable     (DMA_CCR_CIRC&0x00004000)   
#define IS_DMA_CircularMode(SEL)       (((SEL) == DMA_CircularMode_Disable) || \
                                        ((SEL) == DMA_CircularMode_Enable))      
                                                
/** @defgroup DMA_IT
* @{ 
*/
#define DMA_IT_TC0E               DMA_IER_TC0E
#define DMA_IT_TC1E               DMA_IER_TC1E
#define DMA_IT_TE0E               DMA_IER_TE0E
#define DMA_IT_TE1E               DMA_IER_TE1E
#define DMA_IT_CEE            		DMA_IER_CEE
#define IS_DMA_IT(SEL)       (((SEL) == DMA_IT_TC0E)  || \
                              ((SEL) == DMA_IT_TC1E)  || \
                              ((SEL) == DMA_IT_TE0E)  || \
                              ((SEL) == DMA_IT_TE1E)  || \
                              ((SEL) == DMA_IT_CEE))	

/** @defgroup DMA_FLAG
* @{ 
*/
#define DMA_FLAG_TC0F           DMA_SR_TC0F
#define DMA_FLAG_TC1F           DMA_SR_TC1F
#define DMA_FLAG_TE0F           DMA_SR_TE0F
#define DMA_FLAG_TE1F           DMA_SR_TE1F
#define DMA_FLAG_BSY0           DMA_SR_BSY0
#define DMA_FLAG_BSY1           DMA_SR_BSY1
#define DMA_FLAG_CEF          	DMA_SR_CEF

#define IS_DMA_FLAG(SEL)    (((SEL) == DMA_FLAG_TC0F) || \
														 ((SEL) == DMA_FLAG_TC1F) || \
														 ((SEL) == DMA_FLAG_TE0F) || \
														 ((SEL) == DMA_FLAG_TE1F) || \
														 ((SEL) == DMA_FLAG_BSY0) || \
														 ((SEL) == DMA_FLAG_BSY1) || \
														 ((SEL) == DMA_FLAG_CEF))


/** @defgroup DMA_ChannelxPERIPH
* @{ 
*/
#define DMA_ChannelxPERIPH_UART0RX                (DMA_CHAPCR_CHSEL&0x00000000)
#define DMA_ChannelxPERIPH_UART0TX                (DMA_CHAPCR_CHSEL&0x00000001)
#define DMA_ChannelxPERIPH_UART1RX                (DMA_CHAPCR_CHSEL&0x00000002)
#define DMA_ChannelxPERIPH_UART1TX                (DMA_CHAPCR_CHSEL&0x00000003)
#define DMA_ChannelxPERIPH_SPI0RX                 (DMA_CHAPCR_CHSEL&0x00000004)
#define DMA_ChannelxPERIPH_SPI0TX                 (DMA_CHAPCR_CHSEL&0x00000005)
#define DMA_ChannelxPERIPH_SPI1RX                 (DMA_CHAPCR_CHSEL&0x00000006)
#define DMA_ChannelxPERIPH_SPI1TX                 (DMA_CHAPCR_CHSEL&0x00000007)
#define DMA_ChannelxPERIPH_TIMER1                 (DMA_CHAPCR_CHSEL&0x00000008)
#define DMA_ChannelxPERIPH_TIMER5                 (DMA_CHAPCR_CHSEL&0x00000009)
#define DMA_ChannelxPERIPH_TIMER6                 (DMA_CHAPCR_CHSEL&0x0000000A)
#define DMA_ChannelxPERIPH_TIMER7                 (DMA_CHAPCR_CHSEL&0x0000000B)
#define DMA_ChannelxPERIPH_ADC                    (DMA_CHAPCR_CHSEL&0x00000010)

#define IS_DMA_ChannelxPERIPH(SEL)  (((SEL) == DMA_ChannelxPERIPH_UART0RX)    || \
																		 ((SEL) == DMA_ChannelxPERIPH_UART0TX)    || \
																		 ((SEL) == DMA_ChannelxPERIPH_UART1RX)    || \
																		 ((SEL) == DMA_ChannelxPERIPH_UART1TX)    || \
																	   ((SEL) == DMA_ChannelxPERIPH_SPI0RX)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_SPI0TX)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_SPI1RX)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_SPI1TX)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_TIMER1)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_TIMER5)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_TIMER6)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_TIMER7)     || \
																		 ((SEL) == DMA_ChannelxPERIPH_ADC))


/*! function declaration and definition*/
void DMA_Init(DMA_TypeDef* DMAx, DMA_InitTypeDef *DMA_InitStruct);
void DMA_StructInit(DMA_InitTypeDef *DMA_InitStruct);
void DMA_Cmd(DMA_TypeDef* DMAx,FunctionalState NewState);
u32 DMA_GetSourceAddress(DMA_TypeDef* DMAx);
u32 DMA_GetDestinationAddress(DMA_TypeDef* DMAx);
u16 DMA_GetNumberOfData(DMA_TypeDef* DMAx);
void DMA_ITConfig(u32 DMA_IT, FunctionalState NewState);
void DMA_ClearITFlag(u32 DMA_FLAG);
FlagStatus DMA_GetFlagStatus(u32 DMA_FLAG);
void DMA_PeripheralConfig(DMA_TypeDef* DMAx,u32 Peripheral);


#ifdef __cplusplus
}
#endif

#endif 
