/********************************************************************************
  * @file    PT32x030x_pwm.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the pwm firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
#ifndef __PT32x030x_PWM_H
#define __PT32x030x_PWM_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "PT32x030x.h"

/** @defgroup PWM_ALL_PERIPH
* @{ 
*/
#define IS_PWM_ALL_PERIPH(PERIPH) (((PERIPH) == TIM1) || ((PERIPH) == TIM5)  || ((PERIPH) == TIM6) || ((PERIPH) == TIM7))

/** @defgroup PWM_TimeBaseInitTypeDef
* @{ 
*/
typedef struct
{
	u16 PWM_AutoReloadValue;       /*!< Specifies the value to be loaded into the Auto-Reload Register at the next update event.
																		  This parameter can be a number between 0x0000 and 0xFFFF */ 
	
	u8  PWM_InternalClockSource;   /*!< Specifies internal clock source.
																		  This parameter can be value of @ref PWM_InternalClockSource */
	
	u16 PWM_Prescaler; 						 /*!< Specifies the prescaler value used to divide the PCLK.
																		  This parameter can be a number between 0x0000 and 0xFFFF */
			
	u32 PWM_Direction;						 /*!< Specifies the counter mode.
																			This parameter can be value of @ref PWM_Direction */
	
	u32 PWM_CenterAlignedMode;		 /*!< Specifies the center aligned mode.
																			This parameter can be value of @ref PWM_CenterAlignedMode */
	
} PWM_TimeBaseInitTypeDef;

/** @defgroup PWM_InternalClockSource
* @{ 
*/
#define PWM_InternalClockSource_PCLK		0x00000000
#define PWM_InternalClockSource_SYSCLK	PWM_CR1_CLKS
#define IS_PWM_InternalClockSource(SEL)	(((SEL) == PWM_InternalClockSource_PCLK) || \
																				 ((SEL) == PWM_InternalClockSource_SYSCLK))

/** @defgroup PWM_Direction
* @{ 
*/
#define PWM_Direction_Up		(PWM_CR1_DIR&0x00000000) 
#define PWM_Direction_Down	(PWM_CR1_DIR&0x00000200)  
#define IS_PWM_Direction(SEL)      (((SEL) == PWM_Direction_Up) || \
																    ((SEL) == PWM_Direction_Down))   

/** @defgroup PWM_CenterAlignedMode
* @{ 
*/
#define PWM_CenterAlignedMode_Disable	(PWM_CR1_CMS&0x00000000)
#define PWM_CenterAlignedMode_Enable	(PWM_CR1_CMS&0x00000400)
#define IS_PWM_CenterAlignedMode(SEL)   (((SEL) == PWM_CenterAlignedMode_Disable) || \
																				 ((SEL) == PWM_CenterAlignedMode_Enable))  

/** @defgroup PWM_CH_Enum
* @{ 
*/
typedef enum
{
	PWM_Channel_1 = 0,                /*!< PWM channel 1 */
	PWM_Channel_2,                    /*!< PWM channel 2 */
	PWM_Channel_3,                    /*!< PWM channel 3 */
	PWM_Channel_4                     /*!< PWM channel 4 */
}PWM_CH_Enum;

/** @defgroup PWM_OCInitTypeDef
* @{ 
*/
typedef struct
{
	PWM_CH_Enum PWM_Channel;  
	u32 PWM_OCMode; 
	u32 PWM_OCIdleState; 
	u32 PWM_OCNIdleState;
	u32 PWM_OCOutput;  
	u32 PWM_OCNOutput;
	u16 PWM_OCValue;
	u32 PWM_OCPolarity;  
	u32 PWM_OCNPolarity;
} PWM_OCInitTypeDef;

/** @defgroup PWM_Channel
* @{ 
*/
#define IS_PWM_Channel(SEL) (((SEL) == PWM_Channel_1) ||\
														((SEL) == PWM_Channel_2)  ||\
														((SEL) == PWM_Channel_3)  ||\
														((SEL) == PWM_Channel_4))

/** @defgroup PWM_OCMode
* @{ 
*/
#define TIM_OCMode_Timing					(PWM_OCMR_OC1M&0x0000)
#define TIM_OCMode_PWM1						(PWM_OCMR_OC1M&0x0001)
#define TIM_OCMode_PWM2						(PWM_OCMR_OC1M&0x0002)
#define TIM_OCMode_Toggle					(PWM_OCMR_OC1M&0x0003)
#define TIM_OCMode_Active					(PWM_OCMR_OC1M&0x0004)
#define TIM_OCMode_Inactive				(PWM_OCMR_OC1M&0x0005)
#define TIM_OCMode_CompelInactive	(PWM_OCMR_OC1M&0x0006)
#define TIM_OCMode_CompelActive		(PWM_OCMR_OC1M&0x0007)
#define IS_PWM_OCMode(SEL) (((SEL) == TIM_OCMode_Timing) ||\
														((SEL) == TIM_OCMode_PWM1) || \
														((SEL) == TIM_OCMode_PWM2) ||\
														((SEL) == TIM_OCMode_Toggle) || \
														((SEL) == TIM_OCMode_Active) ||\
														((SEL) == TIM_OCMode_Inactive) || \
														((SEL) == TIM_OCMode_CompelInactive) ||\
														((SEL) == TIM_OCMode_CompelActive))

/** @defgroup PWM_OCIdleState
* @{ 
*/
#define  PWM_OCIdleState_Low		0x00000000
#define  PWM_OCIdleState_High		PWM_OCMR_OIS1
#define IS_PWM_OCIdleState(SEL)	(((SEL) == PWM_OCIdleState_Low)    || \
															   ((SEL) == PWM_OCIdleState_High))

/** @defgroup PWM_OCNIdleState
* @{ 
*/
#define  PWM_OCNIdleState_Low		0x00000000
#define  PWM_OCNIdleState_High	PWM_OCMR_OIS1N
#define IS_PWM_OCNIdleState(SEL)	(((SEL) == PWM_OCNIdleState_Low)    || \
																   ((SEL) == PWM_OCNIdleState_High))	

/** @defgroup PWM_OCOutput
* @{ 
*/
#define  PWM_OCOutput_Disable	0x00000000 
#define  PWM_OCOutput_Enable	PWM_OCMR_OC1E
#define IS_PWM_OCOutput(SEL)	(((SEL) == PWM_OCOutput_Disable) || \
															 ((SEL) == PWM_OCOutput_Enable))

/** @defgroup PWM_OCNOutput
* @{ 
*/
#define  PWM_OCNOutput_Disable	0x00000000
#define  PWM_OCNOutput_Enable		PWM_OCMR_OC1NE
#define IS_PWM_OCNOutput(SEL)	(((SEL) == PWM_OCNOutput_Disable) || \
															 ((SEL) == PWM_OCNOutput_Enable))

/** @defgroup PWM_OCPolarity
* @{ 
*/
#define  PWM_OCPolarity_High 	0x00000000
#define  PWM_OCPolarity_Low		PWM_CR3_CC1P
#define IS_PWM_OCPolarity(SEL)	(((SEL) == PWM_OCPolarity_High) || \
																 ((SEL) == PWM_OCPolarity_Low))

/** @defgroup PWM_OCNPolarity
* @{ 
*/
#define  PWM_OCNPolarity_Low 	0x00000000
#define  PWM_OCNPolarity_High PWM_CR3_C1NP
#define IS_PWM_OCNPolarity(SEL)	(((SEL) == PWM_OCNPolarity_High) || \
																 ((SEL) == PWM_OCNPolarity_Low))

/** @defgroup PWM_ICInitTypeDef
* @{ 
*/
typedef struct
{
    PWM_CH_Enum PWM_Channel;              
    u32 PWM_ICRiseCapture;
    u32 PWM_ICFallCapture;
    u32 PWM_ICResetCounter;
    u32 PWM_ICSource;          
    u32 PWM_ICFilter;           
    u32 PWM_ICPrescaler;            
} PWM_ICInitTypeDef;

/** @defgroup PWM_ICRiseCapture
* @{ 
*/
#define  PWM_ICRiseCapture_Disable	0x00000000
#define  PWM_ICRiseCapture_Enable	PWM_CAPR1_IC1R         
#define  IS_PWM_ICRiseCapture(SEL)	(((SEL) == PWM_ICRiseCapture_Disable)    || \
									((SEL) == PWM_ICRiseCapture_Enable))

/** @defgroup PWM_ICFallCapture
* @{ 
*/
#define  PWM_ICFallCapture_Disable	0x00000000
#define  PWM_ICFallCapture_Enable	PWM_CAPR1_IC1F
#define  IS_PWM_ICFallCapture(SEL)	(((SEL) == PWM_ICFallCapture_Disable)    || \
																		 ((SEL) == PWM_ICFallCapture_Enable))	

/** @defgroup PWM_ICResetCounter
* @{ 
*/
#define  PWM_ICResetCounter_Disable	0x00000000
#define  PWM_ICResetCounter_Enable	PWM_CAPR1_IC1RC
#define  IS_PWM_ICResetCounter(SEL)	(((SEL) == PWM_ICResetCounter_Disable)    || \
																		 ((SEL) == PWM_ICResetCounter_Enable))	

/** @defgroup PWM_ICSource
* @{ 
*/
#define PWM_ICSource_ICS1            (PWM_CAPR1_IC1S&0x00010000)
#define PWM_ICSource_ICS2            (PWM_CAPR1_IC1S&0x00020000)
#define PWM_ICSource_ICS3            (PWM_CAPR1_IC1S&0x00030000)
#define PWM_ICSource_ICS4            (PWM_CAPR1_IC1S&0x00040000)
#define PWM_ICSource_TRC             (PWM_CAPR1_IC1S&0x00050000)
#define IS_PWM_ICSource(SEL) (((SEL) == PWM_ICSource_ICS1) ||\
															((SEL) == PWM_ICSource_ICS2) ||\
															((SEL) == PWM_ICSource_ICS3) ||\
															((SEL) == PWM_ICSource_ICS4) ||\
															((SEL) == PWM_ICSource_TRC))

/** @defgroup PWM_ICFilter
* @{ 
*/
#define PWM_ICFilter_0	0x00000000
#define PWM_ICFilter_2	(PWM_CAPR2_IC1FR&0x00000001)
#define PWM_ICFilter_4	(PWM_CAPR2_IC1FR&0x00000002)
#define PWM_ICFilter_8	(PWM_CAPR2_IC1FR&0x00000003)
#define PWM_ICFilter_16	(PWM_CAPR2_IC1FR&0x00000004)
#define PWM_ICFilter_32	(PWM_CAPR2_IC1FR&0x00000005)
#define PWM_ICFilter_64	(PWM_CAPR2_IC1FR&0x00000006)
#define IS_PWM_ICFilter(SEL) (((SEL) == PWM_ICFilter_0) ||\
															((SEL) == PWM_ICFilter_2) ||\
															((SEL) == PWM_ICFilter_4) ||\
															((SEL) == PWM_ICFilter_8) ||\
															((SEL) == PWM_ICFilter_16)||\
															((SEL) == PWM_ICFilter_32)||\
															((SEL) == PWM_ICFilter_64))

/** @defgroup PWM_ICPrescaler
* @{ 
*/
#define PWM_ICPrescaler_0	0x00000000
#define PWM_ICPrescaler_2	(PWM_CAPR2_IC1PSC&0x00000010)
#define PWM_ICPrescaler_4	(PWM_CAPR2_IC1PSC&0x00000020)
#define PWM_ICPrescaler_8	(PWM_CAPR2_IC1PSC&0x00000030)
#define IS_PWM_ICPrescaler(SEL) (((SEL) == PWM_ICPrescaler_0)  ||\
																((SEL) == PWM_ICPrescaler_2) ||\
																((SEL) == PWM_ICPrescaler_4) ||\
																((SEL) == PWM_ICPrescaler_8))
                                
/** @defgroup PWM_BDTRInitTypeDef
* @{ 
*/
typedef struct
{
	u32 PWM_DeadTime;
	u32 PWM_Break;
	u32 PWM_BreakPolarity;
	u32 PWM_BreakSoftwareControl;
	u32 PWM_BreakSource;
	u32 PWM_BreakInputControl; 
} PWM_BDTRInitTypeDef;

/** @defgroup PWM_DeadTime
* @{ 
*/
#define IS_PWM_DeadTime(SEL)	((SEL) <4096)

/** @defgroup PWM_Break
* @{ 
*/
#define PWM_Break_Disable			 (PWM_BDTR_BKE&0x00000) 
#define PWM_Break_Enable				PWM_BDTR_BKE
#define IS_PWM_Break(SEL)	(((SEL) == PWM_Break_Disable) ||\
													 ((SEL) == PWM_Break_Enable))

/** @defgroup PWM_BreakPolarity
* @{ 
*/
#define PWM_BreakPolarity_Low								0x00000000
#define PWM_BreakPolarity_High							PWM_BDTR_BKP 
#define IS_PWM_BreakPolarity(SEL)						 (((SEL) == PWM_BreakPolarity_Low) || \
                                        			((SEL) == PWM_BreakPolarity_High))

/** @defgroup PWM_BreakSoftwareControl
* @{ 
*/
#define PWM_BreakSoftwareControl_Disable	0x00000000
#define PWM_BreakSoftwareControl_Enable		PWM_BDTR_BKSC 
#define IS_PWM_BreakSoftwareControl(SEL)	(((SEL) == PWM_BreakSoftwareControl_Disable) || \
                                           ((SEL) == PWM_BreakSoftwareControl_Enable))

/** @defgroup PWM_BreakSource
* @{ 
*/
#define PWM_BreakSource_TIM1BKIN	((u32)0x00000000) 
#define PWM_BreakSource_HSEFail		((u32)0x00200000)
#define PWM_BreakSource_PLLFail		((u32)0x00300000)
#define PWM_BreakSource_CMP0			((u32)0x00400000)
#define PWM_BreakSource_CMP1			((u32)0x00500000)
#define PWM_BreakSource_PVD				((u32)0x00600000)
#define PWM_BreakSource_Software	((u32)0x00700000)
#define PWM_BreakSource_CMP2			((u32)0x00800000)
#define IS_PWM_BreakSource(SEL)	 (((SEL) == PWM_BreakSource_TIM1BKIN)  ||\
																	((SEL) == PWM_BreakSource_HSEFail) 	 ||\
																	((SEL) == PWM_BreakSource_PLLFail) 	 ||\
																	((SEL) == PWM_BreakSource_CMP0) 		 ||\
																	((SEL) == PWM_BreakSource_CMP1) 		 ||\
																	((SEL) == PWM_BreakSource_PVD) 			 ||\
																	((SEL) == PWM_BreakSource_Software)  ||\
																	((SEL) == PWM_BreakSource_CMP2))

/** @defgroup PWM_BreakInputControl
* @{ 
*/
#define PWM_BreakInput_TIMIdle	0x00000000
#define PWM_BreakInput_TIMOFF	PWM_BDTR_BKIC
#define IS_PWM_BreakInputControl(SEL)	(((SEL) == PWM_BreakInput_TIMIdle) || \
																			 ((SEL) == PWM_BreakInput_TIMOFF))                                                

/** @defgroup PWM_SAMC
* @{ 
*/
#define PWM_SAMC_DIV1	(PWM_CR1_SAMPSC&0x00)
#define PWM_SAMC_DIV2	(PWM_CR1_SAMPSC&0x10)
#define PWM_SAMC_DIV4	(PWM_CR1_SAMPSC&0x20)
#define PWM_SAMC_DIV8	(PWM_CR1_SAMPSC&0x30)
#define PWM_SAMC_DIV16	(PWM_CR1_SAMPSC&0x40)
#define PWM_SAMC_DIV32	(PWM_CR1_SAMPSC&0x50)
#define IS_PWM_SAMC(SEL) (((SEL) == PWM_SAMC_DIV1) 	|| \
													((SEL) == PWM_SAMC_DIV2) 	|| \
													((SEL) == PWM_SAMC_DIV4) 	|| \
													((SEL) == PWM_SAMC_DIV8) 	|| \
													((SEL) == PWM_SAMC_DIV16) || \
													((SEL) == PWM_SAMC_DIV32))	

/** @defgroup PWM_EventSource
* @{ 
*/
#define PWM_EventSource_Update	(PWM_CR1_UG&0x0002)
#define PWM_EventSource_Break	(PWM_BDTR_BKSC&0X80000)
#define IS_PWM_EventSource(SEL) (((SEL) == PWM_EventSource_Update) || \
								((SEL) == PWM_EventSource_Break))	

/** @defgroup PWM_RepeatTimes
* @{ 
*/
#define IS_PWM_RepeatTimes(SEL)             ((SEL) <= 0xF)

/** @defgroup PWM_IT
* @{ 
*/
#define PWM_IT_ARI                   PWM_CR2_ARI
#define PWM_IT_OC1I                  PWM_CR2_OC1I        
#define PWM_IT_OC2I                  PWM_CR2_OC2I      
#define PWM_IT_OC3I                  PWM_CR2_OC3I      
#define PWM_IT_OC4I                  PWM_CR2_OC4I      
#define PWM_IT_IC1I                  PWM_CAPR1_IC1I     
#define PWM_IT_IC2I                  PWM_CAPR1_IC2I     
#define PWM_IT_IC3I                  PWM_CAPR1_IC3I   
#define PWM_IT_IC4I                  PWM_CAPR1_IC4I     
#define PWM_IT_BKI                   PWM_BDTR_BKI 
#define PWM_IT_UIE                   PWM_CR2_UIE
#define IS_PWM_IT(SEL)              (((SEL) == PWM_IT_ARI)  || ((SEL) == PWM_IT_OC1I)  || \
                                    ((SEL) == PWM_IT_OC2I)  || ((SEL) == PWM_IT_OC3I)  || \
                                    ((SEL) == PWM_IT_OC4I)  || ((SEL) == PWM_CAPR1_IC1I)   || \
                                    ((SEL) == PWM_CAPR1_IC2I)  || ((SEL) == PWM_CAPR1_IC3I)   || \
                                    ((SEL) == PWM_CAPR1_IC4I)  || ((SEL) == PWM_BDTR_BKI)   || \
																		((SEL) == PWM_IT_UIE))

/** @defgroup PWM_FLAG
* @{ 
*/
#define PWM_FLAG_ARF                    PWM_SR_ARF
#define PWM_FLAG_OC1F                   PWM_SR_OC1F        
#define PWM_FLAG_OC2F                   PWM_SR_OC2F      
#define PWM_FLAG_OC3F                   PWM_SR_OC3F      
#define PWM_FLAG_OC4F                   PWM_SR_OC4F      
#define PWM_FLAG_IC1R                		PWM_SR_IC1R     
#define PWM_FLAG_IC1F               	  PWM_SR_IC1F     
#define PWM_FLAG_IC2R               	  PWM_SR_IC2R     
#define PWM_FLAG_IC2F               		PWM_SR_IC2F 
#define PWM_FLAG_IC3R               		PWM_SR_IC3R     
#define PWM_FLAG_IC3F               		PWM_SR_IC3F 
#define PWM_FLAG_IC4R                		PWM_SR_IC4R     
#define PWM_FLAG_IC4F               	  PWM_SR_IC4F 
#define PWM_FLAG_BIF                    PWM_SR_BIF 
#define PWM_FLAG_TIF                    PWM_SR_TIF
#define PWM_FLAG_UF                     PWM_SR_UF
#define IS_PWM_FLAG(SEL)                (((SEL) == PWM_FLAG_ARF) || ((SEL) == PWM_FLAG_OC1F) || \
                                            ((SEL) == PWM_FLAG_OC2F) || ((SEL) == PWM_FLAG_OC3F) || \
                                            ((SEL) == PWM_FLAG_OC4F)  || ((SEL) == PWM_FLAG_IC1R) || \
                                            ((SEL) == PWM_FLAG_IC1F) || ((SEL) == PWM_FLAG_IC2R) || \
                                            ((SEL) == PWM_FLAG_IC2F) || ((SEL) == PWM_FLAG_IC3R) || \
                                            ((SEL) == PWM_FLAG_IC3F) || ((SEL) == PWM_FLAG_IC4R) || \
                                            ((SEL) == PWM_FLAG_IC4F) || ((SEL) == PWM_FLAG_BIF) || \
                                            ((SEL) == PWM_FLAG_TIF)     || ((SEL) == PWM_FLAG_UF))		

/** @defgroup PWM_ADCTrigger
* @{ 
*/
#define PWM_ADCTrigger_OC1UE                  PWM_TACR_OC1UE
#define PWM_ADCTrigger_OC1DE                  PWM_TACR_OC1DE
#define PWM_ADCTrigger_OC2UE                  PWM_TACR_OC2UE
#define PWM_ADCTrigger_OC2DE                  PWM_TACR_OC2DE
#define PWM_ADCTrigger_OC3UE                  PWM_TACR_OC3UE
#define PWM_ADCTrigger_OC3DE                  PWM_TACR_OC3DE
#define PWM_ADCTrigger_OC4UE                  PWM_TACR_OC4UE
#define PWM_ADCTrigger_OC4DE                  PWM_TACR_OC4DE
#define PWM_ADCTrigger_UOAE                   PWM_TACR_UOAE
#define PWM_ADCTrigger_DOAE                   PWM_TACR_DOAE
#define PWM_ADCTrigger_TAE                    PWM_TACR_TAE
#define PWM_ADCTrigger_IC1RAE                 PWM_TACR_IC1RAE
#define PWM_ADCTrigger_IC1FAE                 PWM_TACR_IC1FAE
#define PWM_ADCTrigger_IC2RAE                 PWM_TACR_IC2RAE
#define PWM_ADCTrigger_IC2FAE                 PWM_TACR_IC2FAE
#define PWM_ADCTrigger_IC3RAE                 PWM_TACR_IC3RAE
#define PWM_ADCTrigger_IC3FAE                 PWM_TACR_IC3FAE
#define PWM_ADCTrigger_IC4RAE                 PWM_TACR_IC4RAE
#define PWM_ADCTrigger_IC4FAE                 PWM_TACR_IC4FAE
#define IS_PWM_ADCTrigger(SEL)      (((SEL) ==  PWM_ADCTrigger_OC1UE) || ((SEL) == PWM_ADCTrigger_OC1DE) ||\
                                              ((SEL) ==  PWM_ADCTrigger_OC2UE) || ((SEL) == PWM_ADCTrigger_OC2DE) ||\
																							((SEL) ==  PWM_ADCTrigger_OC3UE) || ((SEL) == PWM_ADCTrigger_OC3DE) ||\
																							((SEL) ==  PWM_ADCTrigger_OC4UE) || ((SEL) == PWM_ADCTrigger_OC4DE) ||\
																							((SEL) ==  PWM_ADCTrigger_UOAE)  || ((SEL) == PWM_ADCTrigger_DOAE) ||\
																							((SEL) ==  PWM_ADCTrigger_TAE)   || ((SEL) == PWM_ADCTrigger_IC1RAE)||\
																							((SEL) == PWM_ADCTrigger_IC1FAE) || ((SEL) == PWM_ADCTrigger_IC2RAE)||\
																							((SEL) == PWM_ADCTrigger_IC2FAE) || ((SEL) == PWM_ADCTrigger_IC3RAE)||\
																							((SEL) == PWM_ADCTrigger_IC3FAE) || ((SEL) == PWM_ADCTrigger_IC4RAE)||\
																							((SEL) == PWM_ADCTrigger_IC4FAE))

/** @defgroup PWM_SampleClockPrescaler
* @{ 
*/
#define PWM_SampleClockPrescaler_0             		(PWM_CR1_SAMPSC&0x00000000)
#define PWM_SampleClockPrescaler_2                (PWM_CR1_SAMPSC&0x00000010)
#define PWM_SampleClockPrescaler_4                (PWM_CR1_SAMPSC&0x00000020)
#define PWM_SampleClockPrescaler_8                (PWM_CR1_SAMPSC&0x00000030)
#define PWM_SampleClockPrescaler_16               (PWM_CR1_SAMPSC&0x00000040)
#define PWM_SampleClockPrescaler_32               (PWM_CR1_SAMPSC&0x00000050)
#define IS_PWM_SampleClockPrescaler(SEL)          (((SEL) == PWM_SampleClockPrescaler_0) || ((SEL) == PWM_SampleClockPrescaler_2) ||\
                                              ((SEL) == PWM_SampleClockPrescaler_4)    || ((SEL) == PWM_SampleClockPrescaler_8) ||\
                                            ((SEL) == PWM_SampleClockPrescaler_16)   || ((SEL) == PWM_SampleClockPrescaler_32))

/** @defgroup PWM_DMARequest
* @{ 
*/
#define PWM_DMARequest_ARDE                   PWM_TDCR_ARDE
#define PWM_DMARequest_OC1DE                  PWM_TDCR_OC1DE
#define PWM_DMARequest_OC2DE                  PWM_TDCR_OC2DE
#define PWM_DMARequest_OC3DE                  PWM_TDCR_OC3DE
#define PWM_DMARequest_OC4DE                  PWM_TDCR_OC4DE
#define PWM_DMARequest_IC1RDE                 PWM_TDCR_IC1RDE
#define PWM_DMARequest_IC1FDE                 PWM_TDCR_IC1FDE
#define PWM_DMARequest_IC2RDE                 PWM_TDCR_IC2RDE
#define PWM_DMARequest_IC2FDE                 PWM_TDCR_IC2FDE
#define PWM_DMARequest_IC3RDE                 PWM_TDCR_IC3RDE
#define PWM_DMARequest_IC3FDE                 PWM_TDCR_IC3FDE
#define PWM_DMARequest_IC4RDE                 PWM_TDCR_IC4RDE
#define PWM_DMARequest_IC4FDE                 PWM_TDCR_IC4FDE
#define PWM_DMARequest_TDE                    PWM_TDCR_TDE
#define PWM_DMARequest_UDE                    PWM_TDCR_UDE
#define IS_PWM_DMARequest(SEL)          (((SEL) == PWM_DMARequest_ARDE)  ||  ((SEL) == PWM_DMARequest_OC1DE) ||\
                                        ((SEL) == PWM_DMARequest_OC2DE)  ||  ((SEL) == PWM_DMARequest_OC3DE) ||\
                                        ((SEL) == PWM_DMARequest_OC4DE)  ||  ((SEL) == PWM_DMARequest_IC1RDE) ||\
                                        ((SEL) == PWM_DMARequest_IC1FDE) ||  ((SEL) == PWM_DMARequest_IC2RDE) ||\
                                        ((SEL) == PWM_DMARequest_IC2FDE) ||  ((SEL) == PWM_DMARequest_IC3RDE) ||\
                                        ((SEL) == PWM_DMARequest_IC3FDE) ||  ((SEL) == PWM_DMARequest_IC4RDE) ||\
                                        ((SEL) == PWM_DMARequest_IC4FDE) ||  ((SEL) == PWM_DMARequest_TDE) ||\
                                        ((SEL) == PWM_DMARequest_UDE))

/*! function declaration and definition*/
void PWM_TimeBaseInit(PWM_TypeDef* PWMx, PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_TimeBaseStructInit(PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_OCInit(PWM_TypeDef* PWMx, PWM_OCInitTypeDef* OutInit);
void PWM_OCStructInit(PWM_OCInitTypeDef* OutInit);
void PWM_ICInit(PWM_TypeDef* PWMx, PWM_ICInitTypeDef* CapInit);
void PWM_ICStructInit(PWM_ICInitTypeDef* CapInit);
void PWM_BDTRInit(PWM_TypeDef* PWMx, PWM_BDTRInitTypeDef* BDTRInit);
void PWM_BDTRStructInit(PWM_BDTRInitTypeDef* BDTRInit);


void PWM_SetInterruptAutoreload(PWM_TypeDef* PWMx, u8 value);
void PWM_SetAutoreload(PWM_TypeDef* PWMx, u16 value);
void PWM_SetPrescaler(PWM_TypeDef* PWMx, u16 value);
void PWM_SetOCxValue(PWM_TypeDef* PWMx, u8 PWM_Channel, u16 value);
void PWM_SetICxValue(PWM_TypeDef* PWMx, u8 PWM_Channel, u16 value);
void PWM_SetSAMCClockDivision(PWM_TypeDef* PWMx, u16 PWM_SAMC);
u16 PWM_GetICxValue(PWM_TypeDef* PWMx, u8 PWM_Channel);
u16 PWM_GetCounter(PWM_TypeDef* PWMx);
u16 PWM_GetAutoreload(PWM_TypeDef* PWMx);
u16 PWM_GetPrescaler(PWM_TypeDef* PWMx);


void PWM_GenerateEvent(PWM_TypeDef* PWMx,u32 PWM_EventSource);
void PWM_Cmd(PWM_TypeDef* PWMx, FunctionalState NewState);


void PWM_ITConfig(PWM_TypeDef* PWMx, u32 PWM_INT, FunctionalState NewState);
void PWM_ClearFlag(PWM_TypeDef* PWMx, u32 PWM_FLAG);
FlagStatus PWM_GetFlagStatus(PWM_TypeDef* PWMx, u32 PWM_FLAG);


void PWM_ADCTrigger(PWM_TypeDef* PWMx,u32 CountMode);
void PWM_DMAConfig(PWM_TypeDef* PWMx,u32 DMA_Event ,FunctionalState NewState);
#ifdef __cplusplus
}
#endif

#endif 
