/**
  ******************************************************************************
  * @file    PT32x030x_pwr.h
  * @author  ӦÿŶ
  * @version V1.5.0
  * @date    2022/12/29
  * @brief   This file contains all the functions prototypes for the PWR firmware 
  *          library.
  ******************************************************************************
  * @attention
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x030x_PWR_H
#define PT32x030x_PWR_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x030x.h"

/** @addtogroup PWR
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/


/** @defgroup PWR_PVD_level  
  * @{
  */ 
#define PWR_PVDLevel_0		(PWR_PVDR_PLS&0x00)		
#define PWR_PVDLevel_1		(PWR_PVDR_PLS&0x02)		
#define PWR_PVDLevel_2		(PWR_PVDR_PLS&0x04)		
#define PWR_PVDLevel_3		(PWR_PVDR_PLS&0x06)		
#define PWR_PVDLevel_4		(PWR_PVDR_PLS&0x08)		
#define PWR_PVDLevel_5		(PWR_PVDR_PLS&0x0A)		
#define PWR_PVDLevel_6		(PWR_PVDR_PLS&0x0C)		
#define PWR_PVDLevel_7		(PWR_PVDR_PLS&0x0E)		
#define IS_PWR_PVDLevel(SEL) 		(((SEL) == PWR_PVDLevel_0) || ((SEL) == PWR_PVDLevel_1)|| \
                                 ((SEL) == PWR_PVDLevel_2) || ((SEL) == PWR_PVDLevel_3)|| \
                                 ((SEL) == PWR_PVDLevel_4) || ((SEL) == PWR_PVDLevel_5)|| \
                                 ((SEL) == PWR_PVDLevel_6) || ((SEL) == PWR_PVDLevel_7))
/**
  * @}
  */

/** @defgroup PWR_Sleep_mode_entry 
  * @{
  */
#define PWR_SleepEntry_WFI              ((u8)0x01)
#define PWR_SleepEntry_WFE              ((u8)0x02)
#define IS_PWR_SleepEntry(SEL) 					(((SEL) == PWR_SleepEntry_WFI) || ((SEL) == PWR_SleepEntry_WFE))
/**
  * @}
  */

/** @defgroup PWR_DeepSleep_mode_entry 
  * @{
  */
#define PWR_DeepSleepEntry_WFI           ((u8)0x01)
#define PWR_DeepSleepEntry_WFE           ((u8)0x02)
#define IS_PWR_DeepSleepEntry(SEL) 			 (((SEL) == PWR_DeepSleepEntry_WFI) || ((SEL) == PWR_DeepSleepEntry_WFE))
/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void PWR_PVDLevelConfig(u32 PWR_PVDLevel);
void PWR_PVDCmd(FunctionalState NewState);
void PWR_EnterSleepMode(uint8_t PWR_SleepEntry);
void PWR_EnterDeepSleepMode(uint8_t PWR_DeepSleepEntry);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /* __PT32F0XX_PWR_H */

