  /******************************************************************************
  * @file    PT32x030x_rcc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief    This file contains all the functions prototypes for the SYS firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x030x_RCC_H
#define PT32x030x_RCC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x030x.h"

/** @addtogroup RCC
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/


/* Exported constants --------------------------------------------------------*/
/** @defgroup RCC_Clock_Frequency_Selection
  * @{
  */
#define RCC_SYSCLK									 ((u8)0x01)
#define RCC_HCLK										 ((u8)0x02)
#define RCC_PCLK										 ((u8)0x03)
#define IS_RCC_Clock(SEL)   				 (((SEL) == RCC_SYSCLK)  || ((SEL) == RCC_HCLK)  || ((SEL) == RCC_PCLK))
/**
  * @}
  */ 

/** @defgroup RCC_clock_output_source
  * @{
  */
#define RCC_ClockOutput_HSI			(RCC_MCOR_COSRC&0x00)
#define RCC_ClockOutput_HSE			(RCC_MCOR_COSRC&0x10)
#define RCC_ClockOutput_PLL			(RCC_MCOR_COSRC&0x20)
#define RCC_ClockOutput_LSI			(RCC_MCOR_COSRC&0x30)
#define RCC_ClockOutput_SYS			(RCC_MCOR_COSRC&0x40)
#define RCC_ClockOutput_None		(RCC_MCOR_COSRC&0x70)
#define IS_RCC_ClockOutputSource(SEL)   	(((SEL) == RCC_ClockOutput_HSI)   || \
																					 ((SEL) == RCC_ClockOutput_HSE)   || \
																					 ((SEL) == RCC_ClockOutput_PLL)   || \
																					 ((SEL) == RCC_ClockOutput_LSI)   || \
																					 ((SEL) == RCC_ClockOutput_SYS)   || \
																					 ((SEL) == RCC_ClockOutput_None))
/**
  * @}
  */ 

/** @defgroup RCC_PLL_clock_source
  * @{
  */
#define RCC_PLLClockSource_HSI	(RCC_CFGR_PLLSRC&0x000)
#define RCC_PLLClockSource_HSE	(RCC_CFGR_PLLSRC&0x400)
#define RCC_PLLClockSource_LSI	(RCC_CFGR_PLLSRC&0x800)
#define IS_RCC_PLLClockSource(SEL)   	(((SEL) == RCC_PLLClockSource_HSI)   || \
																			 ((SEL) == RCC_PLLClockSource_HSE)   || \
																			 ((SEL) == RCC_PLLClockSource_LSI))
/**
  * @}
  */ 

/** @defgroup RCC_system_clock_switch_source
  * @{
  */
#define RCC_SystemClock_HSI					(RCC_CFGR_SCW&0x00) 	//Internal Hight CLK Source
#define RCC_SystemClock_HSE					(RCC_CFGR_SCW&0x01) 	//Extern Hight CLK Source
#define RCC_SystemClock_PLL					(RCC_CFGR_SCW&0x02)		//Extern Low CLK Source
#define RCC_SystemClock_LSI					(RCC_CFGR_SCW&0x03) 	//Internal Low CLK Source
#define IS_RCC_SystemClock(SEL) 			(((SEL) == RCC_SystemClock_HSI)   || \
																			 ((SEL) == RCC_SystemClock_HSE) 	|| \
																			 ((SEL) == RCC_SystemClock_PLL) 	|| \
																			 ((SEL) == RCC_SystemClock_LSI))

#define RCC_ClockSource_HSI											(0x00) 	//Internal Hight CLK Source
#define RCC_ClockSource_HSE 										(0x01) 	//Extern Hight CLK  Source
#define RCC_ClockSource_HSEExternal							(0x02) 	//Extern Hight CLK Source
#define RCC_ClockSource_PLL											(0x03)	//Extern Low CLK Source
#define RCC_ClockSource_LSI											(0x04) 	//Internal Low CLK Source
#define IS_RCC_ClockSource(SEL) 			(((SEL) == RCC_ClockSource_HSI)   || \
																			 ((SEL) == RCC_ClockSource_HSE) 	|| \
																			 ((SEL) == RCC_ClockSource_PLL) 	|| \
																			 ((SEL) == RCC_ClockSource_LSI))
/**
  * @}
  */ 

/** @defgroup RCC_Reset_State_Flag
  * @{
  */
#define RCC_FLAG_SFR       		 			 RCC_RSR_SFR
#define RCC_FLAG_IWDGR       				 RCC_RSR_IWDGR
#define RCC_FLAG_HSER      					 RCC_RSR_HSER
#define RCC_FLAG_PLLR       				 RCC_RSR_PLLR
#define RCC_FLAG_POR       			 		 RCC_RSR_POR
#define RCC_FLAG_PINR      		 			 RCC_RSR_PINR
#define RCC_FLAG_PVDR     					 RCC_RSR_PVDR
#define RCC_FLAG_ALL     						(RCC_RSR_SFR|RCC_RSR_IWDGR|RCC_RSR_HSER|RCC_RSR_PLLR|RCC_RSR_POR|RCC_RSR_PINR|RCC_RSR_PVDR)
#define IS_RCC_ResetStateFlag(SEL)       (((SEL) == RCC_FLAG_SFR)  		|| \
																				  ((SEL) == RCC_FLAG_IWDGR)  	|| \
																				  ((SEL) == RCC_FLAG_HSER)   	|| \
																				  ((SEL) == RCC_FLAG_PLLR)	  || \
																				  ((SEL) == RCC_FLAG_POR)			|| \
																				  ((SEL) == RCC_FLAG_PINR) 	  || \
																				  ((SEL) == RCC_FLAG_PVDR)		|| \
																					((SEL) == RCC_FLAG_ALL))
/**
  * @}
  */

/** @defgroup RCC_Reset_selection
  * @{
  */
#define RCC_ResetEnable_HSEFail      					  RCC_RCR_HREN
#define RCC_ResetEnable_PLLFail       					RCC_RCR_PREN
#define RCC_ResetEnable_PVDLowVoltage       	  RCC_RCR_PDRE
#define RCC_ResetEnable_AdvancedSoftware     		RCC_RCR_ASFREN
#define IS_RCC_ResetEnable(SEL)   		((SEL == RCC_ResetEnable_HSEFail)   || \
																			 (SEL == RCC_ResetEnable_PLLFail)   || \
																			 (SEL == RCC_ResetEnable_PVDLowVoltage)   		|| \
																			 (SEL == RCC_ResetEnable_AdvancedSoftware))
/**
  * @}
  */

/** @defgroup RCC_HCLK_prescaler_value
  * @{
  */
#define IS_RCC_HCLKPrescaler(SEL)   	 ((SEL) <= 31)
/**
  * @}
  */

/** @defgroup RCC_PCLK_prescaler_value
  * @{
  */
#define IS_RCC_PCLKPrescaler(SEL)   	 ((SEL) <= 31)
/**
  * @}
  */

/** @defgroup RCC_clock_output_Prescale_value
  * @{
  */
#define RCC_ClockOutputPrescale_None      	(RCC_MCOR_COPRE&0x00)
#define RCC_ClockOutputPrescale_2      		  (RCC_MCOR_COPRE&0x01)
#define RCC_ClockOutputPrescale_4      		  (RCC_MCOR_COPRE&0x02)
#define RCC_ClockOutputPrescale_8      		  (RCC_MCOR_COPRE&0x03)
#define RCC_ClockOutputPrescale_16      		(RCC_MCOR_COPRE&0x04)
#define IS_RCC_ClockOutputPrescale(SEL)   	(((SEL) == RCC_ClockOutputPrescale_None) ||\
										((SEL) == RCC_ClockOutputPrescale_2) 	 ||\
										((SEL) == RCC_ClockOutputPrescale_4) 	 ||\
										((SEL) == RCC_ClockOutputPrescale_8)  	 ||\
										((SEL) == RCC_ClockOutputPrescale_16))
/**
  * @}
  */							
			
/** @defgroup RCC_system_clock_after_wakeup_selection
  * @{
  */
#define RCC_SystemClockAfterWakeUp_HSI						(RCC_CFGR_WKCK&0x000000)
#define RCC_SystemClockAfterWakeUp_PreviousClock	(RCC_CFGR_WKCK&0x100000)
#define IS_RCC_SystemClockAfterWakeUp(SEL)   	(((SEL) == RCC_SystemClockAfterWakeUp_HSI) ||\
																							 ((SEL) == RCC_SystemClockAfterWakeUp_PreviousClock))
/**
  * @}
  */	

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
u32 RCC_GetClockFreq(u8 RCC_Clock);
FlagStatus RCC_GetResetFlagStatus(u32 RCC_FLAG);
void RCC_ClearResetFlag(u32 RCC_FLAG);
void RCC_ResetConfig(u32 ResetSource, FunctionalState NewState);
void RCC_ClockSourceConfig(u32 ClockSource,FunctionalState NewState);
void RCC_AdvancedSoftwareReset(void);
void RCC_SetSystemClock(u32 SystemClockSwitch);
void RCC_SetSystemClockAfterWakeUp(u32 Clock);
void RCC_PLLClockSourceConfig(u32 PLLClockSource);
void RCC_HCLKSetPrescaler(u32 Prescaler);
void RCC_PCLKSetPrescaler(u32 Prescaler);
u8 RCC_GetSystemClockSelection(void);
void RCC_SetMCOSource(u32 ClockSource);
void RCC_MCOSetPrescaler(u32 PrescaleSelcection);

void CLOCK_Cmd(void);
void CLOCK_PLLConfig(void);
void IFMC_WaitConfig(void);
void CLOCK_SystemClockConfig(void);
void CLOCK_MCOConfig(void);
u32  clk_get_sysclk(void);
void SystemInit(void);

/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif 

