/********************************************************************************
  * @file    PT32x030x_spi.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the CRC firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x030x_SPI_H
#define PT32x030x_SPI_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "PT32x030x.h"

/** @defgroup SPI_InitTypeDef
* @{ 
*/
typedef struct
{
  u16 SPI_MasterSlaveMode;            /*!< Specifies the SPI mode
																					 This parameter can be a value of @ref SPI_MasterSlaveMode */
	
  u16 SPI_DataFrameFormat;            /*!< Specifies the SPI data size
																					 This parameter can be a value of @ref SPI_DataFrameFormat */
	
  u16 SPI_ClockPolarity;              /*!< Specifies the serial clock Polarity
																					 This parameter can be a value of @ref SPI_ClockPolarity */
	
  u16 SPI_ClockPhase;                 /*!< Specifies the clock active edge
																					 This parameter can be a value of @ref SPI_ClockPhase */
	
  u16 SPI_CSS;                        /*!< Specifies whether the NSS signal is managed by hardware
																					 This parameter can be a value of @ref SPI_CSS */
	
  u16 SPI_SoftwareControlCSS;         /*!< Specifies Software Control CSS
																				   This parameter can be a value of @ref SPI_SoftwareControlCSS */
	
  u16 SPI_Prescaler;                  /*!< Specifies the Baud Rate prescaler value
																					 This parameter can be a value of @ref SPI_Prescaler */
	
  u16 SPI_BaudRate;                   /*!< Specifies the Baud Rate
																					 This parameter can be a value of @ref SPI_BaudRate */
																					 
}SPI_InitTypeDef;

/** @defgroup SPI_ALL_PERIPH
* @{ 
*/
#define IS_SPI_ALL_PERIPH(SEL) (((SEL) == SPI0) ||((SEL) == SPI1))
                                   
/** @defgroup SPI_MasterSlaveMode
* @{ 
*/
#define SPI_MasterSlaveMode_Master	(SPI_CR2_MSM&0x00000000)
#define SPI_MasterSlaveMode_Slave	(SPI_CR2_MSM&0x00000004)
#define IS_SPI_MasterSlaveMode(SEL)	(((SEL) == SPI_MasterSlaveMode_Master) || \
							((SEL) == SPI_MasterSlaveMode_Slave))

/** @defgroup SPI_DataFrameFormat
* @{ 
*/
#define SPI_DataFrameFormat_4b	(SPI_CR1_DFF&0x03)
#define SPI_DataFrameFormat_5b	(SPI_CR1_DFF&0x04)
#define SPI_DataFrameFormat_6b	(SPI_CR1_DFF&0x05)
#define SPI_DataFrameFormat_7b	(SPI_CR1_DFF&0x06)
#define SPI_DataFrameFormat_8b	(SPI_CR1_DFF&0x07)
#define SPI_DataFrameFormat_9b	(SPI_CR1_DFF&0x08)
#define SPI_DataFrameFormat_10b	(SPI_CR1_DFF&0x09)
#define SPI_DataFrameFormat_11b	(SPI_CR1_DFF&0x0A)
#define SPI_DataFrameFormat_12b	(SPI_CR1_DFF&0x0B)
#define SPI_DataFrameFormat_13b	(SPI_CR1_DFF&0x0C)
#define SPI_DataFrameFormat_14b	(SPI_CR1_DFF&0x0D)
#define SPI_DataFrameFormat_15b	(SPI_CR1_DFF&0x0E)
#define SPI_DataFrameFormat_16b	(SPI_CR1_DFF&0x0F)
#define IS_SPI_DataFrameFormat(SEL)	(((SEL) == SPI_DataFrameFormat_4b) || \
							((SEL) == SPI_DataFrameFormat_5b) || \
							((SEL) == SPI_DataFrameFormat_6b) || \
							((SEL) == SPI_DataFrameFormat_7b) || \
							((SEL) == SPI_DataFrameFormat_8b) || \
							((SEL) == SPI_DataFrameFormat_9b) || \
							((SEL) == SPI_DataFrameFormat_10b) || \
							((SEL) == SPI_DataFrameFormat_11b) || \
							((SEL) == SPI_DataFrameFormat_12b) || \
							((SEL) == SPI_DataFrameFormat_13b) || \
							((SEL) == SPI_DataFrameFormat_14b) || \
							((SEL) == SPI_DataFrameFormat_15b) || \
							((SEL) == SPI_DataFrameFormat_16b))

/** @defgroup SPI_ClockPolarity
* @{ 
*/
#define  SPI_ClockPolarity_Low	(SPI_CR1_CPOL&0x00000000)
#define  SPI_ClockPolarity_High	(SPI_CR1_CPOL&0x00000040)
#define IS_SPI_ClockPolarity(SEL)	(((SEL) == SPI_ClockPolarity_Low) || \
								((SEL) == SPI_ClockPolarity_High))
    
/** @defgroup SPI_ClockPhase
* @{ 
*/
#define  SPI_ClockPhase_1Edge	(SPI_CR1_CPHA&0x00000000)
#define  SPI_ClockPhase_2Edge	(SPI_CR1_CPHA&0x00000080)
#define IS_SPI_ClockPhase(SEL)	(((SEL) == SPI_ClockPhase_1Edge) || \
								((SEL) == SPI_ClockPhase_2Edge))
                           
/** @defgroup SPI_CSS
* @{ 
*/
#define  SPI_CSS_HardwareControl	(SPI_CSS_CSS&0x00000000)
#define  SPI_CSS_SoftwareControl	(SPI_CSS_CSS&0x00000004)
#define IS_SPI_CSS(SEL)		(((SEL) == SPI_CSS_HardwareControl) || \
								((SEL) == SPI_CSS_SoftwareControl))
                                
/** @defgroup SPI_SoftwareControlCSS
* @{ 
*/
#define SPI_SoftwareControlCSS_Low          (SPI_CSS_SWCS&0x00000000)
#define SPI_SoftwareControlCSS_High         (SPI_CSS_SWCS&0x00000008)
#define IS_SPI_SoftwareControlCSS(SEL)	(((SEL) == SPI_SoftwareControlCSS_Low) || \
								((SEL) == SPI_SoftwareControlCSS_High))                                
                         
/** @defgroup SPI_Prescaler
* @{ 
*/
#define IS_SPI_Prescaler(SEL) 			((SEL) < 256)

/** @defgroup SPI_BaudRate
* @{ 
*/
#define IS_SPI_BaudRate(SEL) 				(((SEL) > 1) && ((SEL) < 255))
                                    
/** @defgroup SPI_IT
* @{ 
*/
#define SPI_IT_OVRE 		SPI_IE_OVRE
#define SPI_IT_OTE 			SPI_IE_OTE
#define SPI_IT_RXHE 		SPI_IE_RXHE
#define SPI_IT_TXHE 		SPI_IE_TXHE
#define IS_SPI_IT(SEL)	(((SEL) == SPI_IT_OVRE) || \
												((SEL) == SPI_IT_OTE) 	|| \
												((SEL) == SPI_IT_RXHE) 	|| \
												((SEL) == SPI_IT_TXHE))

/** @defgroup SPI_FLAG
* @{ 
*/
typedef enum
{
	SPI_FLAG_TXE = 0,
	SPI_FLAG_TNF, 
	SPI_FLAG_RXNE,
	SPI_FLAG_RXF,
	SPI_FLAG_BSY, 
	SPI_FLAG_OVR,
	SPI_FLAG_OT, 
	SPI_FLAG_RXH,
	SPI_FLAG_TXH    
} SPI_FLAG;
#define IS_SPI_FLAG(SEL)	(((SEL) == SPI_FLAG_TXE) || \
							((SEL) == SPI_FLAG_TNF) || \
							((SEL) == SPI_FLAG_RXNE) || \
							((SEL) == SPI_FLAG_RXF) || \
							((SEL) == SPI_FLAG_BSY) || \
							((SEL) == SPI_FLAG_OVR) || \
							((SEL) == SPI_FLAG_OT) || \
							((SEL) == SPI_FLAG_RXH) || \
							((SEL) == SPI_FLAG_TXH))

/** @defgroup DMAInitTypeDef
* @{ 
*/
typedef struct
{
  u32 SPI_RxDMARequest;            /*!< Specifies the SPI mode (Master/Slave)*/
  u32 SPI_TxDMARequest;            /*!< Specifies the SPI data size*/
  u32 SPI_DMATrigger;              /*!< Specifies the serial clock Polarity*/																						 
}SPI_DMAInitTypeDef;

/** @defgroup SPI_RxDMARequest
* @{ 
*/
#define  SPI_RxDMARequest_Disable	(SPI_DCR_RXDMAE&0x00000000)
#define  SPI_RxDMARequest_Enable	(SPI_DCR_RXDMAE&0x00000001)
#define IS_SPI_RxDMARequest(SEL)	(((SEL) == SPI_RxDMARequest_Disable) || \
								((SEL) == SPI_RxDMARequest_Enable))

/** @defgroup SPI_TxDMARequest
* @{ 
*/
#define  SPI_TxDMARequest_Disable	(SPI_DCR_TXDMAE&0x00000000)
#define  SPI_TxDMARequest_Enable	(SPI_DCR_TXDMAE&0x00000002)
#define IS_SPI_TxDMARequest(SEL)	(((SEL) == SPI_TxDMARequest_Disable) || \
								((SEL) == SPI_TxDMARequest_Enable))

/** @defgroup SPI_DMATrigger
* @{ 
*/
#define  SPI_DMATrigger_1Frame	(SPI_DCR_DMATC&0x00000000)
#define  SPI_DMATrigger_4Frame	(SPI_DCR_DMATC&0x00000004)
#define IS_SPI_DMATrigger(SEL)	(((SEL) == SPI_DMATrigger_1Frame) || \
								((SEL) == SPI_DMATrigger_4Frame))

/*! function declaration and definition*/
void SPI_Init(SPI_TypeDef* SPIx, SPI_InitTypeDef* SPI_InitStruct);
void SPI_StructInit(SPI_InitTypeDef* SPI_InitStruct);
void SPI_Cmd(SPI_TypeDef* SPIx, FunctionalState NewState);
void SPI_SoftwareControlCSSConfig(SPI_TypeDef* SPIx, u32 SWCS_Signal);
void SPI_SendData(SPI_TypeDef* SPIx, u16 Data);
u16 SPI_ReceiveData(SPI_TypeDef* SPIx);
void SPI_ITConfig(SPI_TypeDef* SPIx, u8 SPI_IT, FunctionalState NewState);
FlagStatus SPI_GetFlagStatus(SPI_TypeDef* SPIx, u16 SPI_FLAG);
void SPI_ClearFlag(SPI_TypeDef* SPIx, u16 SPI_FLAG);
void SPI_DMATransferInit(SPI_TypeDef* SPIx,SPI_DMAInitTypeDef* SPI_DMAInitStruct);
  
#ifdef __cplusplus
}
#endif

#endif 


