
  /******************************************************************************
  * @file    PT32x030x_tim.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief    This file contains all the functions prototypes for the TIM firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x030x_TIM_H
#define PT32x030x_TIM_H

#ifdef __cplusplus
extern "C" {
#endif
/* Includes ------------------------------------------------------------------*/
#include "PT32x030x.h"


/** @addtogroup TIM
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  TIM Time Base Init structure definition  
  * @note   This structure is used with all TIMx except for TIM0 , TIM1, TIM5, TIM6 and TIM7.
  */
	
typedef struct
{
	u16	TIM_AutoReload;                /*!< Specifies the value to be loaded into the Auto-Reload Register at the next update event.
																					This parameter can be a number between 0x0000 and 0xFFFF */ 
	
	u16	TIM_Prescaler;                 /*!< Specifies the prescaler value used to divide the PCLK.
																					This parameter can be a number between 0x0000 and 0xFFFF */
	
	u32	TIM_Direction;              	 /*!< Specifies the counter mode.
																					This parameter can be value of @ref TIM_counter_direction_selection */

	
} TIM_TimeBaseInitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IS_TIM_ALL_PERIPH 
  * @{
  */
#define IS_TIM_ALL_PERIPH(SEL)            	(((SEL) == TIM2) ||((SEL) == TIM3)||((SEL) == TIM4))
/**
  * @}
  */

/** @defgroup TIM_counter_direction_selection 
  * @{
  */
#define TIM_Direction_Down	(TIM_CR2_DIR&0x00000000)
#define TIM_Direction_Up		(TIM_CR2_DIR)
#define IS_TIM_Direction(SEL)	(((SEL) == TIM_Direction_Up) || \
							((SEL) == TIM_Direction_Down))
/**
  * @}
  */
	


/** @defgroup TIM_interrupt_selection
  * @{
  */
#define TIM_IT_ARI		TIM_CR2_ARI
#define IS_TIM_IT(SEL)	((SEL)  == TIM_IT_ARI)
/**
  * @}
  */

/** @defgroup TIM_flag_selection
  * @{
  */
#define TIM_FLAG_ARF	TIM_SR_ARF
#define IS_TIM_FLAG(SEL)		((SEL) == TIM_FLAG_ARF)
/**
  * @}
  */



/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/
void TIM_TimeBaseInit(TIMx_TypeDef* TIMx, TIM_TimeBaseInitTypeDef* TimeBaseInit);
void TIM_TimeBaseStructInit(TIM_TimeBaseInitTypeDef* TimeBaseInit);
void TIM_SetPrescaler(TIMx_TypeDef* TIMx, u16 Prescaler);
void TIM_SetAutoreload(TIMx_TypeDef* TIMx, u16 Reload);
void TIM_SetCounter(TIMx_TypeDef* TIMx, u16 Counter);
u16 TIM_GetCounter(TIMx_TypeDef* TIMx);
u16 TIM_GetPrescaler(TIMx_TypeDef* TIMx);
void TIM_Cmd(TIMx_TypeDef* TIMx, FunctionalState NewState);
void TIM_ITConfig(TIMx_TypeDef* TIMx, u32 TIM_IT, FunctionalState NewState);
FlagStatus TIM_GetFlagStatus(TIMx_TypeDef* TIMx, u32 TIM_FLAG);
void TIM_ClearFlag(TIMx_TypeDef* TIMx, u32 TIM_FLAG);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif


