/********************************************************************************
  * @file    PT32x030x_uart.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2022/12/29 
  * @brief   This file contains all the functions prototypes for the uart firmware 
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
    
#ifndef PT32x030x_UART_H
#define PT32x030x_UART_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x030x.h"

/** @defgroup UART_InitTypeDef
* @{ 
*/
typedef struct
{
	u32 UART_BaudRate; 							/*!< This member configures the USART communication baud rate.
																			 @note UART_BaudRate shouldn't over 3Mbps. */
	
	u16 UART_WordLengthAndParity;		/*!< Specifies the number of data bits transmitted or 
																			 received in a frame and the parity mode.
                                       This parameter can be a value of @ref UART_WordLengthAndParity */
	
	u16 UART_StopBitLength;					/*!< Specifies the number of stop bits transmitted.
                                       This parameter can be a value of @ref UART_StopBitLength */
	
	u16 UART_ParityMode;						/*!< Specifies the parity mode.
                                       This parameter can be a value of @ref UART_ParityMode */
	
	u16 UART_Receiver;							/*!< Specifies the receive enable.
                                       This parameter can be a value of @ref UART_Receiver */
	
	u16 UART_LoopbackMode;					/*!< Specifies the lookback mode enable.
                                       This parameter can be a value of @ref UART_LoopbackMode */
	
} UART_InitTypeDef;


/** @defgroup UART_FIFO
* @{ 
*/
#define FIFO_RX          0
#define FIFO_TX          1
#define IS_UART_FIFO(SEL)   (((SEL) == FIFO_RX) || \
                                     ((SEL) == FIFO_TX))

/** @defgroup UART_ALL_PERIPH
* @{ 
*/
#define IS_UART_ALL_PERIPH(SEL)   (((SEL) == UART0) || \
                                     ((SEL) == UART1))

/** @defgroup USART_PERIPH
* @{ 
*/
#define IS_USART_PERIPH(SEL)      (((SEL) == UART0) || \
                                     ((SEL) == UART1))

/** @defgroup UART_BaudRate
* @{ 
*/
#define IS_UART_BaudRate(SEL)	(((SEL) > 46) && ((SEL) <= 3000000))

/** @defgroup UART_WordLengthAndParity
* @{ 
*/
#define UART_WordLengthAndParity_8D     (UART_CR_WP&0x00000001)
#define UART_WordLengthAndParity_7DP    (UART_CR_WP&0x00000003)
#define UART_WordLengthAndParity_9D     (UART_CR_WP&0x00000004)
#define UART_WordLengthAndParity_8DP    (UART_CR_WP&0x00000007)
#define IS_UART_WordLengthAndParity(SEL)	(((SEL) == UART_WordLengthAndParity_8D) || \
								((SEL) == UART_WordLengthAndParity_7DP) || \
								((SEL) == UART_WordLengthAndParity_9D) || \
								((SEL) == UART_WordLengthAndParity_8DP))

/** @defgroup UART_StopBitLength
* @{ 
*/
#define  UART_StopBitLength_0P5		                 (UART_CR_STOP&0x00000000)
#define  UART_StopBitLength_1		                 (UART_CR_STOP&0x00000008)
#define  UART_StopBitLength_1P5		                 (UART_CR_STOP&0x00000010)
#define  UART_StopBitLength_2		                 (UART_CR_STOP&0x00000018)
#define IS_UART_StopBitLength(SEL)	(((SEL) == UART_StopBitLength_0P5) || \
								((SEL) == UART_StopBitLength_1) || \
								((SEL) == UART_StopBitLength_1P5) || \
								((SEL) == UART_StopBitLength_2))

/** @defgroup UART_ParityMode
* @{ 
*/
#define UART_ParityMode_Odd		    (UART_CR_PS&0x00000020)
#define UART_ParityMode_Even		(UART_CR_PS&0x00000000)
#define IS_UART_ParityMode(SEL)		(((SEL) == UART_ParityMode_Odd) || \
								((SEL) == UART_ParityMode_Even))
							
/** @defgroup UART_Receiver
* @{ 
*/								
#define  UART_Receiver_Enable	    (UART_CR_RE&0x00000100)	
#define  UART_Receiver_Disable	    (UART_CR_RE&0x00000000)	
#define IS_UART_Receiver(SEL)		(((SEL) == UART_Receiver_Enable) || \
								((SEL) == UART_Receiver_Disable))

/** @defgroup UART_LoopbackMode
* @{ 
*/
#define UART_LoopbackMode_Disable		(UART_CR_LPB&0x00000000)
#define UART_LoopbackMode_Enable		(UART_CR_LPB&0x00000040)
#define IS_UART_LoopbackMode(SEL)	(((SEL) == UART_LoopbackMode_Disable) || \
									((SEL) == UART_LoopbackMode_Enable))

/** @defgroup UART_Data
* @{ 
*/
#define IS_UART_Data(SEL)             ((SEL) <= 0x1FF)

/** @defgroup UART_DutyCycle
* @{ 
*/
#define IS_UART_DutyCycle(SEL)   ((SEL) <= 0x00000064)

/** @defgroup UART_SingleLineDirection
* @{ 
*/
#define UART_SingleLineDirection_Tx		(UART_CR_SLDS&0x00200000)
#define UART_SingleLineDirection_Rx		(UART_CR_SLDS&0x00000000)
#define IS_UART_SingleLineDirection(SEL)	(((SEL) == UART_SingleLineDirection_Tx) || \
								((SEL) == UART_SingleLineDirection_Rx))

/** @defgroup UART_TimeOut
* @{ 
*/
#define IS_UART_TimeOut(SEL)    ((SEL) <= 0xFF)

/** @defgroup UART_InfraredBaudRate
* @{ 
*/
#define UART_InfraredBaudRate_600bps		(UART_IMCR_IRBD&0x00000000)
#define UART_InfraredBaudRate_1200bps		(UART_IMCR_IRBD&0x00000010)
#define UART_InfraredBaudRate_2400bps		(UART_IMCR_IRBD&0x00000020)
#define IS_UART_InfraredBaudRate(SEL)	(((SEL) == UART_InfraredBaudRate_600bps) || \
                                        ((SEL) == UART_InfraredBaudRate_1200bps) || \
                                        ((SEL) == UART_InfraredBaudRate_2400bps))

/** @defgroup UART_FLAG
* @{ 
*/
#define UART_FLAG_RXNE      UART_SR_RXNE
#define UART_FLAG_RXHF      UART_SR_RXHF
#define UART_FLAG_RXF	    	UART_SR_RXF
#define UART_FLAG_RXCOT	    UART_SR_RXCOT
#define UART_FLAG_IDLE	    UART_SR_IDLE
#define UART_FLAG_PE	   	  UART_SR_PE
#define UART_FLAG_FE	    	UART_SR_FE
#define UART_FLAG_OVR	    	UART_SR_OVR
#define UART_FLAG_TXE	    	UART_SR_TXE
#define UART_FLAG_TXHE	    UART_SR_TXHE
#define UART_FLAG_TXF	    	UART_SR_TXF
#define UART_FLAG_TXO	    	UART_SR_TXO
#define IS_UART_FLAG(SEL)		(((SEL) == UART_FLAG_RXNE)   || \
														((SEL) == UART_FLAG_RXHF)    || \
														((SEL) == UART_FLAG_RXF)     || \
														((SEL) == UART_FLAG_RXCOT)   || \
														((SEL) == UART_FLAG_IDLE)    || \
														((SEL) == UART_FLAG_PE)    	 || \
														((SEL) == UART_FLAG_FE)   	 || \
														((SEL) == UART_FLAG_OVR) 		 || \
														((SEL) == UART_FLAG_TXE)     || \
														((SEL) == UART_FLAG_TXHE)    || \
														((SEL) == UART_FLAG_TXF)     || \
														((SEL) == UART_FLAG_TXO))

/** @defgroup UART_IT
* @{ 
*/
#define UART_IT_RXNE        UART_IE_RXNEI
#define UART_IT_RXHF        UART_IE_RXHFI
#define UART_IT_RXF	        UART_IE_RXFI
#define UART_IT_RXCOT	    	UART_IE_RXCOTI
#define UART_IT_IDLE	    	UART_IE_IDLEI
#define UART_IT_PE	        UART_IE_PEI
#define UART_IT_FE	        UART_IE_FEI
#define UART_IT_OVR	        UART_IE_OVRI
#define UART_IT_TXE	        UART_IE_TXEI
#define UART_IT_TXHE	    	UART_IE_TXHEI
#define UART_IT_TXF	        UART_IE_TXFI
#define UART_IT_TXO	        UART_IE_TXOI
#define IS_UART_IT(SEL)		(((SEL) == UART_IT_RXNE)    || \
														((SEL) == UART_IT_RXHF)   || \
														((SEL) == UART_IT_RXF)    || \
														((SEL) == UART_IT_RXCOT)  || \
														((SEL) == UART_IT_IDLE)   || \
														((SEL) == UART_IT_PE)    	|| \
														((SEL) == UART_IT_FE)   	|| \
														((SEL) == UART_IT_OVR) 		|| \
														((SEL) == UART_IT_TXE)    || \
														((SEL) == UART_IT_TXHE)   || \
														((SEL) == UART_IT_TXF)    || \
														((SEL) == UART_IT_TXO))

/*! function declaration and definition*/
void UART_Init(UART_TypeDef* UARTx, UART_InitTypeDef* UART_InitStruct);
void UART_StructInit(UART_InitTypeDef* UART_InitStruct);
void UART_Cmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_SetTimeOut(UART_TypeDef* UARTx, u32 TimeOut);
void UART_SendData(UART_TypeDef* UARTx, u16 Data);
u16 UART_ReceiveData(UART_TypeDef* UARTx);
void UART_FifoReset(UART_TypeDef * UARTx,  u8 UART_FIFO);
void UART_IrDACmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_IrDAPolarityConfig(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_IrDABaudRateConfig(UART_TypeDef* UARTx, u8 IrDABaudRate);
void UART_IrDADutyCycleConfig(UART_TypeDef* UARTx, u8 IrDADutyCycle);
void UART_HalfDuplexCmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_HalfDuplexDirectionConfig(UART_TypeDef* UARTx, u32 Direction);
void UART_ITConfig(UART_TypeDef* UARTx, u32 UART_IT, FunctionalState NewState);
FlagStatus UART_GetFlagStatus(UART_TypeDef* UARTx, u32 UART_FLAG);
void UART_ClearFlag(UART_TypeDef* UARTx, u32 UART_CLEAR_FLAG);
ITStatus UART_GetITStatus(UART_TypeDef* UARTx, u32 UART_IT);
  
#ifdef __cplusplus
}
#endif

#endif 


