/******************************************************************************
  * @file    PT32x03x_Beep.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief   This file provides firmware functions to manage the following
  *          functionalities of the Beep peripheral:
  *           + Initialization and Configuration
  *           + Enable or Disble
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "PT32x030x_beep.h"

/** @defgroup BEEP
  * @brief BEEP driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define DeInit_CR_MASK ((u32)0x00000000)
#define DeInit_CR_MASK ((u32)0x00000000)
#define Init_CR_MASK 	 ((u32)0xFFFFFF01)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Initializes the BEEP peripheral according to the specified
  *         parameters in the Beep_InitStruct.
  * @param  Beep_InitStruct: pointer to a Beep_InitTypeDef structure that contains
  *         the configuration information for the specified BEEP peripheral.
  * @retval None
  */
void Beep_Init(Beep_InitTypeDef* Beep_InitStruct)
{
	u32 tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_BEEP_ClockDivider(Beep_InitStruct->BEEP_ClockDivider));
	assert_param(IS_BEEP_Prescaler(Beep_InitStruct->BEEP_PrescalerValue));
	/*  */
	tmpreg = BEEP->CR;
	/*  */
	tmpreg &= Init_CR_MASK;
	/*  */
	tmpreg  |= ((u32)(Beep_InitStruct->BEEP_ClockDivider));
	tmpreg  |= ((u32)((Beep_InitStruct->BEEP_PrescalerValue) << 0x01));
	BEEP->CR = tmpreg;
}

/**
  * @brief  Enables or disables the BEEP peripheral.
  * @param  NewState: new state of the BEEP peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void Beep_Cmd(FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	if (NewState != DISABLE)
	{
		/**/
		BEEP->CR |= BEEP_CR_EN;
	}
	else
	{
		/* */
		BEEP->CR &= ~((u32)BEEP_CR_EN);
	}
}
/**
  * @brief  DeInit BEEP peripheral.
  * @param  None.
  * @retval None.
  */
void Beep_DeInit(void)
{
	BEEP->CR = DeInit_CR_MASK;
	BEEP->HCR = DeInit_CR_MASK;
}


/**
  * @brief  Enables or disables the  BEEP High Sink .
	* @param  BEEPx: select the BEEPx peripheral.
  * @param  NewState: new state of the BEEP peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void Beep_HighSinkConfig(BEEP_TypeDef* BEEPx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_BEEP_ALL_PERIPH(BEEPx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	if (NewState != DISABLE)
	{
		/**/
		BEEPx->HCR |= BEEP_HCR_BEEP1E;
	}
	else
	{
		/* */
		BEEPx->HCR &= ~((u32)BEEP_HCR_BEEP1E);
	}
}

/**
  * @}
  */
