/******************************************************************************
  * @file    PT32x030x_ldac.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/12/29
  * @brief   This file provides firmware functions to manage the following
  *          functionalities of the CMP/OPA peripheral:
  *           + Initialization and Configuration
  *           + Interrupts and flags management
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Includes ------------------------------------------------------------------*/
#include "PT32x030x_ldac.h"

/** @defgroup LDAC
  * @brief LDAC driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Set the LDAC Value.
  * @param  LDACx: select the LDACx peripheral.
  * @param  LDAC_Data: LDAC_DACValue can be a number between 0x00 and 0x1F.
  * @retval None.
  */
void LDAC_SetData(LDAC_TypeDef* LDACx, u32 LDAC_Data)
{
	/* Check the parameters */
	assert_param(IS_LDAC_ALL_PERIPH(LDACx));
	assert_param(IS_LDAC_Value(LDAC_Data));
	
	/* Write LDACx value */
	LDACx->CR = LDAC_Data;
}

/**
  * @brief  Enables or disables the specified LDAC peripheral.
  * @param  LDACx: select the LDAC peripheral.
  * @param  NewState: new state of the LDACx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void LDAC_Cmd(LDAC_TypeDef* LDACx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_LDAC_ALL_PERIPH(LDACx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	
	if (NewState != DISABLE)
	{
		/* Enable the selected LDACx peripheral */
		LDACx->CR |= LDAC_CR_EN;
	}
	else
	{
		/* Disable the selected LDACx peripheral */
		LDACx->CR &= (uint32_t)~LDAC_CR_EN;
	}
}

/**
  * @}
  */
